from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.ImageAcquisition
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.System.Variant
import win32more.Windows.Win32.UI.WindowsAndMessaging
WIA_DIP_DEV_ID: UInt32 = 2
WIA_DIP_DEV_ID_STR: String = 'Unique Device ID'
WIA_DIP_VEND_DESC: UInt32 = 3
WIA_DIP_VEND_DESC_STR: String = 'Manufacturer'
WIA_DIP_DEV_DESC: UInt32 = 4
WIA_DIP_DEV_DESC_STR: String = 'Description'
WIA_DIP_DEV_TYPE: UInt32 = 5
WIA_DIP_DEV_TYPE_STR: String = 'Type'
WIA_DIP_PORT_NAME: UInt32 = 6
WIA_DIP_PORT_NAME_STR: String = 'Port'
WIA_DIP_DEV_NAME: UInt32 = 7
WIA_DIP_DEV_NAME_STR: String = 'Name'
WIA_DIP_SERVER_NAME: UInt32 = 8
WIA_DIP_SERVER_NAME_STR: String = 'Server'
WIA_DIP_REMOTE_DEV_ID: UInt32 = 9
WIA_DIP_REMOTE_DEV_ID_STR: String = 'Remote Device ID'
WIA_DIP_UI_CLSID: UInt32 = 10
WIA_DIP_UI_CLSID_STR: String = 'UI Class ID'
WIA_DIP_HW_CONFIG: UInt32 = 11
WIA_DIP_HW_CONFIG_STR: String = 'Hardware Configuration'
WIA_DIP_BAUDRATE: UInt32 = 12
WIA_DIP_BAUDRATE_STR: String = 'BaudRate'
WIA_DIP_STI_GEN_CAPABILITIES: UInt32 = 13
WIA_DIP_STI_GEN_CAPABILITIES_STR: String = 'STI Generic Capabilities'
WIA_DIP_WIA_VERSION: UInt32 = 14
WIA_DIP_WIA_VERSION_STR: String = 'WIA Version'
WIA_DIP_DRIVER_VERSION: UInt32 = 15
WIA_DIP_DRIVER_VERSION_STR: String = 'Driver Version'
WIA_DIP_PNP_ID: UInt32 = 16
WIA_DIP_PNP_ID_STR: String = 'PnP ID String'
WIA_DIP_STI_DRIVER_VERSION: UInt32 = 17
WIA_DIP_STI_DRIVER_VERSION_STR: String = 'STI Driver Version'
WIA_DPA_FIRMWARE_VERSION: UInt32 = 1026
WIA_DPA_FIRMWARE_VERSION_STR: String = 'Firmware Version'
WIA_DPA_CONNECT_STATUS: UInt32 = 1027
WIA_DPA_CONNECT_STATUS_STR: String = 'Connect Status'
WIA_DPA_DEVICE_TIME: UInt32 = 1028
WIA_DPA_DEVICE_TIME_STR: String = 'Device Time'
WIA_DPC_PICTURES_TAKEN: UInt32 = 2050
WIA_DPC_PICTURES_TAKEN_STR: String = 'Pictures Taken'
WIA_DPC_PICTURES_REMAINING: UInt32 = 2051
WIA_DPC_PICTURES_REMAINING_STR: String = 'Pictures Remaining'
WIA_DPC_EXPOSURE_MODE: UInt32 = 2052
WIA_DPC_EXPOSURE_MODE_STR: String = 'Exposure Mode'
WIA_DPC_EXPOSURE_COMP: UInt32 = 2053
WIA_DPC_EXPOSURE_COMP_STR: String = 'Exposure Compensation'
WIA_DPC_EXPOSURE_TIME: UInt32 = 2054
WIA_DPC_EXPOSURE_TIME_STR: String = 'Exposure Time'
WIA_DPC_FNUMBER: UInt32 = 2055
WIA_DPC_FNUMBER_STR: String = 'F Number'
WIA_DPC_FLASH_MODE: UInt32 = 2056
WIA_DPC_FLASH_MODE_STR: String = 'Flash Mode'
WIA_DPC_FOCUS_MODE: UInt32 = 2057
WIA_DPC_FOCUS_MODE_STR: String = 'Focus Mode'
WIA_DPC_FOCUS_MANUAL_DIST: UInt32 = 2058
WIA_DPC_FOCUS_MANUAL_DIST_STR: String = 'Focus Manual Dist'
WIA_DPC_ZOOM_POSITION: UInt32 = 2059
WIA_DPC_ZOOM_POSITION_STR: String = 'Zoom Position'
WIA_DPC_PAN_POSITION: UInt32 = 2060
WIA_DPC_PAN_POSITION_STR: String = 'Pan Position'
WIA_DPC_TILT_POSITION: UInt32 = 2061
WIA_DPC_TILT_POSITION_STR: String = 'Tilt Position'
WIA_DPC_TIMER_MODE: UInt32 = 2062
WIA_DPC_TIMER_MODE_STR: String = 'Timer Mode'
WIA_DPC_TIMER_VALUE: UInt32 = 2063
WIA_DPC_TIMER_VALUE_STR: String = 'Timer Value'
WIA_DPC_POWER_MODE: UInt32 = 2064
WIA_DPC_POWER_MODE_STR: String = 'Power Mode'
WIA_DPC_BATTERY_STATUS: UInt32 = 2065
WIA_DPC_BATTERY_STATUS_STR: String = 'Battery Status'
WIA_DPC_THUMB_WIDTH: UInt32 = 2066
WIA_DPC_THUMB_WIDTH_STR: String = 'Thumbnail Width'
WIA_DPC_THUMB_HEIGHT: UInt32 = 2067
WIA_DPC_THUMB_HEIGHT_STR: String = 'Thumbnail Height'
WIA_DPC_PICT_WIDTH: UInt32 = 2068
WIA_DPC_PICT_WIDTH_STR: String = 'Picture Width'
WIA_DPC_PICT_HEIGHT: UInt32 = 2069
WIA_DPC_PICT_HEIGHT_STR: String = 'Picture Height'
WIA_DPC_DIMENSION: UInt32 = 2070
WIA_DPC_DIMENSION_STR: String = 'Dimension'
WIA_DPC_COMPRESSION_SETTING: UInt32 = 2071
WIA_DPC_COMPRESSION_SETTING_STR: String = 'Compression Setting'
WIA_DPC_FOCUS_METERING: UInt32 = 2072
WIA_DPC_FOCUS_METERING_STR: String = 'Focus Metering Mode'
WIA_DPC_TIMELAPSE_INTERVAL: UInt32 = 2073
WIA_DPC_TIMELAPSE_INTERVAL_STR: String = 'Timelapse Interval'
WIA_DPC_TIMELAPSE_NUMBER: UInt32 = 2074
WIA_DPC_TIMELAPSE_NUMBER_STR: String = 'Timelapse Number'
WIA_DPC_BURST_INTERVAL: UInt32 = 2075
WIA_DPC_BURST_INTERVAL_STR: String = 'Burst Interval'
WIA_DPC_BURST_NUMBER: UInt32 = 2076
WIA_DPC_BURST_NUMBER_STR: String = 'Burst Number'
WIA_DPC_EFFECT_MODE: UInt32 = 2077
WIA_DPC_EFFECT_MODE_STR: String = 'Effect Mode'
WIA_DPC_DIGITAL_ZOOM: UInt32 = 2078
WIA_DPC_DIGITAL_ZOOM_STR: String = 'Digital Zoom'
WIA_DPC_SHARPNESS: UInt32 = 2079
WIA_DPC_SHARPNESS_STR: String = 'Sharpness'
WIA_DPC_CONTRAST: UInt32 = 2080
WIA_DPC_CONTRAST_STR: String = 'Contrast'
WIA_DPC_CAPTURE_MODE: UInt32 = 2081
WIA_DPC_CAPTURE_MODE_STR: String = 'Capture Mode'
WIA_DPC_CAPTURE_DELAY: UInt32 = 2082
WIA_DPC_CAPTURE_DELAY_STR: String = 'Capture Delay'
WIA_DPC_EXPOSURE_INDEX: UInt32 = 2083
WIA_DPC_EXPOSURE_INDEX_STR: String = 'Exposure Index'
WIA_DPC_EXPOSURE_METERING_MODE: UInt32 = 2084
WIA_DPC_EXPOSURE_METERING_MODE_STR: String = 'Exposure Metering Mode'
WIA_DPC_FOCUS_METERING_MODE: UInt32 = 2085
WIA_DPC_FOCUS_METERING_MODE_STR: String = 'Focus Metering Mode'
WIA_DPC_FOCUS_DISTANCE: UInt32 = 2086
WIA_DPC_FOCUS_DISTANCE_STR: String = 'Focus Distance'
WIA_DPC_FOCAL_LENGTH: UInt32 = 2087
WIA_DPC_FOCAL_LENGTH_STR: String = 'Focus Length'
WIA_DPC_RGB_GAIN: UInt32 = 2088
WIA_DPC_RGB_GAIN_STR: String = 'RGB Gain'
WIA_DPC_WHITE_BALANCE: UInt32 = 2089
WIA_DPC_WHITE_BALANCE_STR: String = 'White Balance'
WIA_DPC_UPLOAD_URL: UInt32 = 2090
WIA_DPC_UPLOAD_URL_STR: String = 'Upload URL'
WIA_DPC_ARTIST: UInt32 = 2091
WIA_DPC_ARTIST_STR: String = 'Artist'
WIA_DPC_COPYRIGHT_INFO: UInt32 = 2092
WIA_DPC_COPYRIGHT_INFO_STR: String = 'Copyright Info'
WIA_DPS_HORIZONTAL_BED_SIZE: UInt32 = 3074
WIA_DPS_HORIZONTAL_BED_SIZE_STR: String = 'Horizontal Bed Size'
WIA_DPS_VERTICAL_BED_SIZE: UInt32 = 3075
WIA_DPS_VERTICAL_BED_SIZE_STR: String = 'Vertical Bed Size'
WIA_DPS_HORIZONTAL_SHEET_FEED_SIZE: UInt32 = 3076
WIA_DPS_HORIZONTAL_SHEET_FEED_SIZE_STR: String = 'Horizontal Sheet Feed Size'
WIA_DPS_VERTICAL_SHEET_FEED_SIZE: UInt32 = 3077
WIA_DPS_VERTICAL_SHEET_FEED_SIZE_STR: String = 'Vertical Sheet Feed Size'
WIA_DPS_SHEET_FEEDER_REGISTRATION: UInt32 = 3078
WIA_DPS_SHEET_FEEDER_REGISTRATION_STR: String = 'Sheet Feeder Registration'
WIA_DPS_HORIZONTAL_BED_REGISTRATION: UInt32 = 3079
WIA_DPS_HORIZONTAL_BED_REGISTRATION_STR: String = 'Horizontal Bed Registration'
WIA_DPS_VERTICAL_BED_REGISTRATION: UInt32 = 3080
WIA_DPS_VERTICAL_BED_REGISTRATION_STR: String = 'Vertical Bed Registration'
WIA_DPS_PLATEN_COLOR: UInt32 = 3081
WIA_DPS_PLATEN_COLOR_STR: String = 'Platen Color'
WIA_DPS_PAD_COLOR: UInt32 = 3082
WIA_DPS_PAD_COLOR_STR: String = 'Pad Color'
WIA_DPS_FILTER_SELECT: UInt32 = 3083
WIA_DPS_FILTER_SELECT_STR: String = 'Filter Select'
WIA_DPS_DITHER_SELECT: UInt32 = 3084
WIA_DPS_DITHER_SELECT_STR: String = 'Dither Select'
WIA_DPS_DITHER_PATTERN_DATA: UInt32 = 3085
WIA_DPS_DITHER_PATTERN_DATA_STR: String = 'Dither Pattern Data'
WIA_DPS_DOCUMENT_HANDLING_CAPABILITIES: UInt32 = 3086
WIA_DPS_DOCUMENT_HANDLING_CAPABILITIES_STR: String = 'Document Handling Capabilities'
WIA_DPS_DOCUMENT_HANDLING_STATUS: UInt32 = 3087
WIA_DPS_DOCUMENT_HANDLING_STATUS_STR: String = 'Document Handling Status'
WIA_DPS_DOCUMENT_HANDLING_SELECT: UInt32 = 3088
WIA_DPS_DOCUMENT_HANDLING_SELECT_STR: String = 'Document Handling Select'
WIA_DPS_DOCUMENT_HANDLING_CAPACITY: UInt32 = 3089
WIA_DPS_DOCUMENT_HANDLING_CAPACITY_STR: String = 'Document Handling Capacity'
WIA_DPS_OPTICAL_XRES: UInt32 = 3090
WIA_DPS_OPTICAL_XRES_STR: String = 'Horizontal Optical Resolution'
WIA_DPS_OPTICAL_YRES: UInt32 = 3091
WIA_DPS_OPTICAL_YRES_STR: String = 'Vertical Optical Resolution'
WIA_DPS_ENDORSER_CHARACTERS: UInt32 = 3092
WIA_DPS_ENDORSER_CHARACTERS_STR: String = 'Endorser Characters'
WIA_DPS_ENDORSER_STRING: UInt32 = 3093
WIA_DPS_ENDORSER_STRING_STR: String = 'Endorser String'
WIA_DPS_SCAN_AHEAD_PAGES: UInt32 = 3094
WIA_DPS_SCAN_AHEAD_PAGES_STR: String = 'Scan Ahead Pages'
WIA_DPS_MAX_SCAN_TIME: UInt32 = 3095
WIA_DPS_MAX_SCAN_TIME_STR: String = 'Max Scan Time'
WIA_DPS_PAGES: UInt32 = 3096
WIA_DPS_PAGES_STR: String = 'Pages'
WIA_DPS_PAGE_SIZE: UInt32 = 3097
WIA_DPS_PAGE_SIZE_STR: String = 'Page Size'
WIA_DPS_PAGE_WIDTH: UInt32 = 3098
WIA_DPS_PAGE_WIDTH_STR: String = 'Page Width'
WIA_DPS_PAGE_HEIGHT: UInt32 = 3099
WIA_DPS_PAGE_HEIGHT_STR: String = 'Page Height'
WIA_DPS_PREVIEW: UInt32 = 3100
WIA_DPS_PREVIEW_STR: String = 'Preview'
WIA_DPS_TRANSPARENCY: UInt32 = 3101
WIA_DPS_TRANSPARENCY_STR: String = 'Transparency Adapter'
WIA_DPS_TRANSPARENCY_SELECT: UInt32 = 3102
WIA_DPS_TRANSPARENCY_SELECT_STR: String = 'Transparency Adapter Select'
WIA_DPS_SHOW_PREVIEW_CONTROL: UInt32 = 3103
WIA_DPS_SHOW_PREVIEW_CONTROL_STR: String = 'Show preview control'
WIA_DPS_MIN_HORIZONTAL_SHEET_FEED_SIZE: UInt32 = 3104
WIA_DPS_MIN_HORIZONTAL_SHEET_FEED_SIZE_STR: String = 'Minimum Horizontal Sheet Feed Size'
WIA_DPS_MIN_VERTICAL_SHEET_FEED_SIZE: UInt32 = 3105
WIA_DPS_MIN_VERTICAL_SHEET_FEED_SIZE_STR: String = 'Minimum Vertical Sheet Feed Size'
WIA_DPS_TRANSPARENCY_CAPABILITIES: UInt32 = 3106
WIA_DPS_TRANSPARENCY_CAPABILITIES_STR: String = 'Transparency Adapter Capabilities'
WIA_DPS_TRANSPARENCY_STATUS: UInt32 = 3107
WIA_DPS_TRANSPARENCY_STATUS_STR: String = 'Transparency Adapter Status'
WIA_DPF_MOUNT_POINT: UInt32 = 3330
WIA_DPF_MOUNT_POINT_STR: String = 'Directory mount point'
WIA_DPV_LAST_PICTURE_TAKEN: UInt32 = 3586
WIA_DPV_LAST_PICTURE_TAKEN_STR: String = 'Last Picture Taken'
WIA_DPV_IMAGES_DIRECTORY: UInt32 = 3587
WIA_DPV_IMAGES_DIRECTORY_STR: String = 'Images Directory'
WIA_DPV_DSHOW_DEVICE_PATH: UInt32 = 3588
WIA_DPV_DSHOW_DEVICE_PATH_STR: String = 'Directshow Device Path'
WIA_IPA_ITEM_NAME: UInt32 = 4098
WIA_IPA_ITEM_NAME_STR: String = 'Item Name'
WIA_IPA_FULL_ITEM_NAME: UInt32 = 4099
WIA_IPA_FULL_ITEM_NAME_STR: String = 'Full Item Name'
WIA_IPA_ITEM_TIME: UInt32 = 4100
WIA_IPA_ITEM_TIME_STR: String = 'Item Time Stamp'
WIA_IPA_ITEM_FLAGS: UInt32 = 4101
WIA_IPA_ITEM_FLAGS_STR: String = 'Item Flags'
WIA_IPA_ACCESS_RIGHTS: UInt32 = 4102
WIA_IPA_ACCESS_RIGHTS_STR: String = 'Access Rights'
WIA_IPA_DATATYPE: UInt32 = 4103
WIA_IPA_DATATYPE_STR: String = 'Data Type'
WIA_IPA_DEPTH: UInt32 = 4104
WIA_IPA_DEPTH_STR: String = 'Bits Per Pixel'
WIA_IPA_PREFERRED_FORMAT: UInt32 = 4105
WIA_IPA_PREFERRED_FORMAT_STR: String = 'Preferred Format'
WIA_IPA_FORMAT: UInt32 = 4106
WIA_IPA_FORMAT_STR: String = 'Format'
WIA_IPA_COMPRESSION: UInt32 = 4107
WIA_IPA_COMPRESSION_STR: String = 'Compression'
WIA_IPA_TYMED: UInt32 = 4108
WIA_IPA_TYMED_STR: String = 'Media Type'
WIA_IPA_CHANNELS_PER_PIXEL: UInt32 = 4109
WIA_IPA_CHANNELS_PER_PIXEL_STR: String = 'Channels Per Pixel'
WIA_IPA_BITS_PER_CHANNEL: UInt32 = 4110
WIA_IPA_BITS_PER_CHANNEL_STR: String = 'Bits Per Channel'
WIA_IPA_PLANAR: UInt32 = 4111
WIA_IPA_PLANAR_STR: String = 'Planar'
WIA_IPA_PIXELS_PER_LINE: UInt32 = 4112
WIA_IPA_PIXELS_PER_LINE_STR: String = 'Pixels Per Line'
WIA_IPA_BYTES_PER_LINE: UInt32 = 4113
WIA_IPA_BYTES_PER_LINE_STR: String = 'Bytes Per Line'
WIA_IPA_NUMBER_OF_LINES: UInt32 = 4114
WIA_IPA_NUMBER_OF_LINES_STR: String = 'Number of Lines'
WIA_IPA_GAMMA_CURVES: UInt32 = 4115
WIA_IPA_GAMMA_CURVES_STR: String = 'Gamma Curves'
WIA_IPA_ITEM_SIZE: UInt32 = 4116
WIA_IPA_ITEM_SIZE_STR: String = 'Item Size'
WIA_IPA_COLOR_PROFILE: UInt32 = 4117
WIA_IPA_COLOR_PROFILE_STR: String = 'Color Profiles'
WIA_IPA_MIN_BUFFER_SIZE: UInt32 = 4118
WIA_IPA_MIN_BUFFER_SIZE_STR: String = 'Buffer Size'
WIA_IPA_BUFFER_SIZE: UInt32 = 4118
WIA_IPA_BUFFER_SIZE_STR: String = 'Buffer Size'
WIA_IPA_REGION_TYPE: UInt32 = 4119
WIA_IPA_REGION_TYPE_STR: String = 'Region Type'
WIA_IPA_ICM_PROFILE_NAME: UInt32 = 4120
WIA_IPA_ICM_PROFILE_NAME_STR: String = 'Color Profile Name'
WIA_IPA_APP_COLOR_MAPPING: UInt32 = 4121
WIA_IPA_APP_COLOR_MAPPING_STR: String = 'Application Applies Color Mapping'
WIA_IPA_PROP_STREAM_COMPAT_ID: UInt32 = 4122
WIA_IPA_PROP_STREAM_COMPAT_ID_STR: String = 'Stream Compatibility ID'
WIA_IPA_FILENAME_EXTENSION: UInt32 = 4123
WIA_IPA_FILENAME_EXTENSION_STR: String = 'Filename extension'
WIA_IPA_SUPPRESS_PROPERTY_PAGE: UInt32 = 4124
WIA_IPA_SUPPRESS_PROPERTY_PAGE_STR: String = 'Suppress a property page'
WIA_IPC_THUMBNAIL: UInt32 = 5122
WIA_IPC_THUMBNAIL_STR: String = 'Thumbnail Data'
WIA_IPC_THUMB_WIDTH: UInt32 = 5123
WIA_IPC_THUMB_WIDTH_STR: String = 'Thumbnail Width'
WIA_IPC_THUMB_HEIGHT: UInt32 = 5124
WIA_IPC_THUMB_HEIGHT_STR: String = 'Thumbnail Height'
WIA_IPC_AUDIO_AVAILABLE: UInt32 = 5125
WIA_IPC_AUDIO_AVAILABLE_STR: String = 'Audio Available'
WIA_IPC_AUDIO_DATA_FORMAT: UInt32 = 5126
WIA_IPC_AUDIO_DATA_FORMAT_STR: String = 'Audio Format'
WIA_IPC_AUDIO_DATA: UInt32 = 5127
WIA_IPC_AUDIO_DATA_STR: String = 'Audio Data'
WIA_IPC_NUM_PICT_PER_ROW: UInt32 = 5128
WIA_IPC_NUM_PICT_PER_ROW_STR: String = 'Pictures per Row'
WIA_IPC_SEQUENCE: UInt32 = 5129
WIA_IPC_SEQUENCE_STR: String = 'Sequence Number'
WIA_IPC_TIMEDELAY: UInt32 = 5130
WIA_IPC_TIMEDELAY_STR: String = 'Time Delay'
WIA_IPS_CUR_INTENT: UInt32 = 6146
WIA_IPS_CUR_INTENT_STR: String = 'Current Intent'
WIA_IPS_XRES: UInt32 = 6147
WIA_IPS_XRES_STR: String = 'Horizontal Resolution'
WIA_IPS_YRES: UInt32 = 6148
WIA_IPS_YRES_STR: String = 'Vertical Resolution'
WIA_IPS_XPOS: UInt32 = 6149
WIA_IPS_XPOS_STR: String = 'Horizontal Start Position'
WIA_IPS_YPOS: UInt32 = 6150
WIA_IPS_YPOS_STR: String = 'Vertical Start Position'
WIA_IPS_XEXTENT: UInt32 = 6151
WIA_IPS_XEXTENT_STR: String = 'Horizontal Extent'
WIA_IPS_YEXTENT: UInt32 = 6152
WIA_IPS_YEXTENT_STR: String = 'Vertical Extent'
WIA_IPS_PHOTOMETRIC_INTERP: UInt32 = 6153
WIA_IPS_PHOTOMETRIC_INTERP_STR: String = 'Photometric Interpretation'
WIA_IPS_BRIGHTNESS: UInt32 = 6154
WIA_IPS_BRIGHTNESS_STR: String = 'Brightness'
WIA_IPS_CONTRAST: UInt32 = 6155
WIA_IPS_CONTRAST_STR: String = 'Contrast'
WIA_IPS_ORIENTATION: UInt32 = 6156
WIA_IPS_ORIENTATION_STR: String = 'Orientation'
WIA_IPS_ROTATION: UInt32 = 6157
WIA_IPS_ROTATION_STR: String = 'Rotation'
WIA_IPS_MIRROR: UInt32 = 6158
WIA_IPS_MIRROR_STR: String = 'Mirror'
WIA_IPS_THRESHOLD: UInt32 = 6159
WIA_IPS_THRESHOLD_STR: String = 'Threshold'
WIA_IPS_INVERT: UInt32 = 6160
WIA_IPS_INVERT_STR: String = 'Invert'
WIA_IPS_WARM_UP_TIME: UInt32 = 6161
WIA_IPS_WARM_UP_TIME_STR: String = 'Lamp Warm up Time'
WIA_DPS_USER_NAME: UInt32 = 3112
WIA_DPS_USER_NAME_STR: String = 'User Name'
WIA_DPS_SERVICE_ID: UInt32 = 3113
WIA_DPS_SERVICE_ID_STR: String = 'Service ID'
WIA_DPS_DEVICE_ID: UInt32 = 3114
WIA_DPS_DEVICE_ID_STR: String = 'Device ID'
WIA_DPS_GLOBAL_IDENTITY: UInt32 = 3115
WIA_DPS_GLOBAL_IDENTITY_STR: String = 'Global Identity'
WIA_DPS_SCAN_AVAILABLE_ITEM: UInt32 = 3116
WIA_DPS_SCAN_AVAILABLE_ITEM_STR: String = 'Scan Available Item'
WIA_IPS_DESKEW_X: UInt32 = 6162
WIA_IPS_DESKEW_X_STR: String = 'DeskewX'
WIA_IPS_DESKEW_Y: UInt32 = 6163
WIA_IPS_DESKEW_Y_STR: String = 'DeskewY'
WIA_IPS_SEGMENTATION: UInt32 = 6164
WIA_IPS_SEGMENTATION_STR: String = 'Segmentation'
WIA_SEGMENTATION_FILTER_STR: String = 'SegmentationFilter'
WIA_IMAGEPROC_FILTER_STR: String = 'ImageProcessingFilter'
WIA_IPS_MAX_HORIZONTAL_SIZE: UInt32 = 6165
WIA_IPS_MAX_HORIZONTAL_SIZE_STR: String = 'Maximum Horizontal Scan Size'
WIA_IPS_MAX_VERTICAL_SIZE: UInt32 = 6166
WIA_IPS_MAX_VERTICAL_SIZE_STR: String = 'Maximum Vertical Scan Size'
WIA_IPS_MIN_HORIZONTAL_SIZE: UInt32 = 6167
WIA_IPS_MIN_HORIZONTAL_SIZE_STR: String = 'Minimum Horizontal Scan Size'
WIA_IPS_MIN_VERTICAL_SIZE: UInt32 = 6168
WIA_IPS_MIN_VERTICAL_SIZE_STR: String = 'Minimum Vertical Scan Size'
WIA_IPS_TRANSFER_CAPABILITIES: UInt32 = 6169
WIA_IPS_TRANSFER_CAPABILITIES_STR: String = 'Transfer Capabilities'
WIA_IPS_SHEET_FEEDER_REGISTRATION: UInt32 = 3078
WIA_IPS_SHEET_FEEDER_REGISTRATION_STR: String = 'Sheet Feeder Registration'
WIA_IPS_DOCUMENT_HANDLING_SELECT: UInt32 = 3088
WIA_IPS_DOCUMENT_HANDLING_SELECT_STR: String = 'Document Handling Select'
WIA_IPS_OPTICAL_XRES: UInt32 = 3090
WIA_IPS_OPTICAL_XRES_STR: String = 'Horizontal Optical Resolution'
WIA_IPS_OPTICAL_YRES: UInt32 = 3091
WIA_IPS_OPTICAL_YRES_STR: String = 'Vertical Optical Resolution'
WIA_IPS_PAGES: UInt32 = 3096
WIA_IPS_PAGES_STR: String = 'Pages'
WIA_IPS_PAGE_SIZE: UInt32 = 3097
WIA_IPS_PAGE_SIZE_STR: String = 'Page Size'
WIA_IPS_PAGE_WIDTH: UInt32 = 3098
WIA_IPS_PAGE_WIDTH_STR: String = 'Page Width'
WIA_IPS_PAGE_HEIGHT: UInt32 = 3099
WIA_IPS_PAGE_HEIGHT_STR: String = 'Page Height'
WIA_IPS_PREVIEW: UInt32 = 3100
WIA_IPS_PREVIEW_STR: String = 'Preview'
WIA_IPS_SHOW_PREVIEW_CONTROL: UInt32 = 3103
WIA_IPS_SHOW_PREVIEW_CONTROL_STR: String = 'Show preview control'
WIA_IPS_FILM_SCAN_MODE: UInt32 = 3104
WIA_IPS_FILM_SCAN_MODE_STR: String = 'Film Scan Mode'
WIA_IPS_LAMP: UInt32 = 3105
WIA_IPS_LAMP_STR: String = 'Lamp'
WIA_IPS_LAMP_AUTO_OFF: UInt32 = 3106
WIA_IPS_LAMP_AUTO_OFF_STR: String = 'Lamp Auto Off'
WIA_IPS_AUTO_DESKEW: UInt32 = 3107
WIA_IPS_AUTO_DESKEW_STR: String = 'Automatic Deskew'
WIA_IPS_SUPPORTS_CHILD_ITEM_CREATION: UInt32 = 3108
WIA_IPS_SUPPORTS_CHILD_ITEM_CREATION_STR: String = 'Supports Child Item Creation'
WIA_IPS_XSCALING: UInt32 = 3109
WIA_IPS_XSCALING_STR: String = 'Horizontal Scaling'
WIA_IPS_YSCALING: UInt32 = 3110
WIA_IPS_YSCALING_STR: String = 'Vertical Scaling'
WIA_IPS_PREVIEW_TYPE: UInt32 = 3111
WIA_IPS_PREVIEW_TYPE_STR: String = 'Preview Type'
WIA_IPA_ITEM_CATEGORY: UInt32 = 4125
WIA_IPA_ITEM_CATEGORY_STR: String = 'Item Category'
WIA_IPA_UPLOAD_ITEM_SIZE: UInt32 = 4126
WIA_IPA_UPLOAD_ITEM_SIZE_STR: String = 'Upload Item Size'
WIA_IPA_ITEMS_STORED: UInt32 = 4127
WIA_IPA_ITEMS_STORED_STR: String = 'Items Stored'
WIA_IPA_RAW_BITS_PER_CHANNEL: UInt32 = 4128
WIA_IPA_RAW_BITS_PER_CHANNEL_STR: String = 'Raw Bits Per Channel'
WIA_IPS_FILM_NODE_NAME: UInt32 = 4129
WIA_IPS_FILM_NODE_NAME_STR: String = 'Film Node Name'
WIA_IPS_PRINTER_ENDORSER: UInt32 = 4130
WIA_IPS_PRINTER_ENDORSER_STR: String = 'Printer/Endorser'
WIA_IPS_PRINTER_ENDORSER_ORDER: UInt32 = 4131
WIA_IPS_PRINTER_ENDORSER_ORDER_STR: String = 'Printer/Endorser Order'
WIA_IPS_PRINTER_ENDORSER_COUNTER: UInt32 = 4132
WIA_IPS_PRINTER_ENDORSER_COUNTER_STR: String = 'Printer/Endorser Counter'
WIA_IPS_PRINTER_ENDORSER_STEP: UInt32 = 4133
WIA_IPS_PRINTER_ENDORSER_STEP_STR: String = 'Printer/Endorser Step'
WIA_IPS_PRINTER_ENDORSER_XOFFSET: UInt32 = 4134
WIA_IPS_PRINTER_ENDORSER_XOFFSET_STR: String = 'Printer/Endorser Horizontal Offset'
WIA_IPS_PRINTER_ENDORSER_YOFFSET: UInt32 = 4135
WIA_IPS_PRINTER_ENDORSER_YOFFSET_STR: String = 'Printer/Endorser Vertical Offset'
WIA_IPS_PRINTER_ENDORSER_NUM_LINES: UInt32 = 4136
WIA_IPS_PRINTER_ENDORSER_NUM_LINES_STR: String = 'Printer/Endorser Lines'
WIA_IPS_PRINTER_ENDORSER_STRING: UInt32 = 4137
WIA_IPS_PRINTER_ENDORSER_STRING_STR: String = 'Printer/Endorser String'
WIA_IPS_PRINTER_ENDORSER_VALID_CHARACTERS: UInt32 = 4138
WIA_IPS_PRINTER_ENDORSER_VALID_CHARACTERS_STR: String = 'Printer/Endorser Valid Characters'
WIA_IPS_PRINTER_ENDORSER_VALID_FORMAT_SPECIFIERS: UInt32 = 4139
WIA_IPS_PRINTER_ENDORSER_VALID_FORMAT_SPECIFIERS_STR: String = 'Printer/Endorser Valid Format Specifiers'
WIA_IPS_PRINTER_ENDORSER_TEXT_UPLOAD: UInt32 = 4140
WIA_IPS_PRINTER_ENDORSER_TEXT_UPLOAD_STR: String = 'Printer/Endorser Text Upload'
WIA_IPS_PRINTER_ENDORSER_TEXT_DOWNLOAD: UInt32 = 4141
WIA_IPS_PRINTER_ENDORSER_TEXT_DOWNLOAD_STR: String = 'Printer/Endorser Text Download'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS: UInt32 = 4142
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_STR: String = 'Printer/Endorser Graphics'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_POSITION: UInt32 = 4143
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_POSITION_STR: String = 'Printer/Endorser Graphics Position'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MIN_WIDTH: UInt32 = 4144
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MIN_WIDTH_STR: String = 'Printer/Endorser Graphics Minimum Width'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MAX_WIDTH: UInt32 = 4145
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MAX_WIDTH_STR: String = 'Printer/Endorser Graphics Maximum Width'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MIN_HEIGHT: UInt32 = 4146
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MIN_HEIGHT_STR: String = 'Printer/Endorser Graphics Minimum Height'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MAX_HEIGHT: UInt32 = 4147
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_MAX_HEIGHT_STR: String = 'Printer/Endorser Graphics Maximum Height'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_UPLOAD: UInt32 = 4148
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_UPLOAD_STR: String = 'Printer/Endorser Graphics Upload'
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_DOWNLOAD: UInt32 = 4149
WIA_IPS_PRINTER_ENDORSER_GRAPHICS_DOWNLOAD_STR: String = 'Printer/Endorser Graphics Download'
WIA_IPS_BARCODE_READER: UInt32 = 4150
WIA_IPS_BARCODE_READER_STR: String = 'Barcode Reader'
WIA_IPS_MAXIMUM_BARCODES_PER_PAGE: UInt32 = 4151
WIA_IPS_MAXIMUM_BARCODES_PER_PAGE_STR: String = 'Maximum Barcodes Per Page'
WIA_IPS_BARCODE_SEARCH_DIRECTION: UInt32 = 4152
WIA_IPS_BARCODE_SEARCH_DIRECTION_STR: String = 'Barcode Search Direction'
WIA_IPS_MAXIMUM_BARCODE_SEARCH_RETRIES: UInt32 = 4153
WIA_IPS_MAXIMUM_BARCODE_SEARCH_RETRIES_STR: String = 'Barcode Search Retries'
WIA_IPS_BARCODE_SEARCH_TIMEOUT: UInt32 = 4154
WIA_IPS_BARCODE_SEARCH_TIMEOUT_STR: String = 'Barcode Search Timeout'
WIA_IPS_SUPPORTED_BARCODE_TYPES: UInt32 = 4155
WIA_IPS_SUPPORTED_BARCODE_TYPES_STR: String = 'Supported Barcode Types'
WIA_IPS_ENABLED_BARCODE_TYPES: UInt32 = 4156
WIA_IPS_ENABLED_BARCODE_TYPES_STR: String = 'Enabled Barcode Types'
WIA_IPS_PATCH_CODE_READER: UInt32 = 4157
WIA_IPS_PATCH_CODE_READER_STR: String = 'Patch Code Reader'
WIA_IPS_SUPPORTED_PATCH_CODE_TYPES: UInt32 = 4162
WIA_IPS_SUPPORTED_PATCH_CODE_TYPES_STR: String = 'Supported Patch Code Types'
WIA_IPS_ENABLED_PATCH_CODE_TYPES: UInt32 = 4163
WIA_IPS_ENABLED_PATCH_CODE_TYPES_STR: String = 'Enabled Path Code Types'
WIA_IPS_MICR_READER: UInt32 = 4164
WIA_IPS_MICR_READER_STR: String = 'MICR Reader'
WIA_IPS_JOB_SEPARATORS: UInt32 = 4165
WIA_IPS_JOB_SEPARATORS_STR: String = 'Job Separators'
WIA_IPS_LONG_DOCUMENT: UInt32 = 4166
WIA_IPS_LONG_DOCUMENT_STR: String = 'Long Document'
WIA_IPS_BLANK_PAGES: UInt32 = 4167
WIA_IPS_BLANK_PAGES_STR: String = 'Blank Pages'
WIA_IPS_MULTI_FEED: UInt32 = 4168
WIA_IPS_MULTI_FEED_STR: String = 'Multi-Feed'
WIA_IPS_MULTI_FEED_SENSITIVITY: UInt32 = 4169
WIA_IPS_MULTI_FEED_SENSITIVITY_STR: String = 'Multi-Feed Sensitivity'
WIA_IPS_AUTO_CROP: UInt32 = 4170
WIA_IPS_AUTO_CROP_STR: String = 'Auto-Crop'
WIA_IPS_OVER_SCAN: UInt32 = 4171
WIA_IPS_OVER_SCAN_STR: String = 'Overscan'
WIA_IPS_OVER_SCAN_LEFT: UInt32 = 4172
WIA_IPS_OVER_SCAN_LEFT_STR: String = 'Overscan Left'
WIA_IPS_OVER_SCAN_RIGHT: UInt32 = 4173
WIA_IPS_OVER_SCAN_RIGHT_STR: String = 'Overscan Right'
WIA_IPS_OVER_SCAN_TOP: UInt32 = 4174
WIA_IPS_OVER_SCAN_TOP_STR: String = 'Overscan Top'
WIA_IPS_OVER_SCAN_BOTTOM: UInt32 = 4175
WIA_IPS_OVER_SCAN_BOTTOM_STR: String = 'Overscan Bottom'
WIA_IPS_COLOR_DROP: UInt32 = 4176
WIA_IPS_COLOR_DROP_STR: String = 'Color Drop'
WIA_IPS_COLOR_DROP_RED: UInt32 = 4177
WIA_IPS_COLOR_DROP_RED_STR: String = 'Color Drop Red'
WIA_IPS_COLOR_DROP_GREEN: UInt32 = 4178
WIA_IPS_COLOR_DROP_GREEN_STR: String = 'Color Drop Green'
WIA_IPS_COLOR_DROP_BLUE: UInt32 = 4179
WIA_IPS_COLOR_DROP_BLUE_STR: String = 'Color Drop Blue'
WIA_IPS_SCAN_AHEAD: UInt32 = 4180
WIA_IPS_SCAN_AHEAD_STR: String = 'Scan Ahead'
WIA_IPS_SCAN_AHEAD_CAPACITY: UInt32 = 4181
WIA_IPS_SCAN_AHEAD_CAPACITY_STR: String = 'Scan Ahead Capacity'
WIA_IPS_FEEDER_CONTROL: UInt32 = 4182
WIA_IPS_FEEDER_CONTROL_STR: String = 'Feeder Control'
WIA_IPS_PRINTER_ENDORSER_PADDING: UInt32 = 4183
WIA_IPS_PRINTER_ENDORSER_PADDING_STR: String = 'Printer/Endorser Padding'
WIA_IPS_PRINTER_ENDORSER_FONT_TYPE: UInt32 = 4184
WIA_IPS_PRINTER_ENDORSER_FONT_TYPE_STR: String = 'Printer/Endorser Font Type'
WIA_IPS_ALARM: UInt32 = 4185
WIA_IPS_ALARM_STR: String = 'Alarm'
WIA_IPS_PRINTER_ENDORSER_INK: UInt32 = 4186
WIA_IPS_PRINTER_ENDORSER_INK_STR: String = 'Printer/Endorser Ink'
WIA_IPS_PRINTER_ENDORSER_CHARACTER_ROTATION: UInt32 = 4187
WIA_IPS_PRINTER_ENDORSER_CHARACTER_ROTATION_STR: String = 'Printer/Endorser Character Rotation'
WIA_IPS_PRINTER_ENDORSER_MAX_CHARACTERS: UInt32 = 4188
WIA_IPS_PRINTER_ENDORSER_MAX_CHARACTERS_STR: String = 'Printer/Endorser Maximum Characters'
WIA_IPS_PRINTER_ENDORSER_MAX_GRAPHICS: UInt32 = 4189
WIA_IPS_PRINTER_ENDORSER_MAX_GRAPHICS_STR: String = 'Printer/Endorser Maximum Graphics'
WIA_IPS_PRINTER_ENDORSER_COUNTER_DIGITS: UInt32 = 4190
WIA_IPS_PRINTER_ENDORSER_COUNTER_DIGITS_STR: String = 'Printer/Endorser Counter Digits'
WIA_IPS_COLOR_DROP_MULTI: UInt32 = 4191
WIA_IPS_COLOR_DROP_MULTI_STR: String = 'Color Drop Multiple'
WIA_IPS_BLANK_PAGES_SENSITIVITY: UInt32 = 4192
WIA_IPS_BLANK_PAGES_SENSITIVITY_STR: String = 'Blank Pages Sensitivity'
WIA_IPS_MULTI_FEED_DETECT_METHOD: UInt32 = 4193
WIA_IPS_MULTI_FEED_DETECT_METHOD_STR: String = 'Multi-Feed Detection Method'
WIA_CATEGORY_FINISHED_FILE: Guid = Guid('{ff2b77ca-cf84-432b-a735-3a130dde2a88}')
WIA_CATEGORY_FLATBED: Guid = Guid('{fb607b1f-43f3-488b-855b-fb703ec342a6}')
WIA_CATEGORY_FEEDER: Guid = Guid('{fe131934-f84c-42ad-8da4-6129cddd7288}')
WIA_CATEGORY_FILM: Guid = Guid('{fcf65be7-3ce3-4473-af85-f5d37d21b68a}')
WIA_CATEGORY_ROOT: Guid = Guid('{f193526f-59b8-4a26-9888-e16e4f97ce10}')
WIA_CATEGORY_FOLDER: Guid = Guid('{c692a446-6f5a-481d-85bb-92e2e86fd30a}')
WIA_CATEGORY_FEEDER_FRONT: Guid = Guid('{4823175c-3b28-487b-a7e6-eebc17614fd1}')
WIA_CATEGORY_FEEDER_BACK: Guid = Guid('{61ca74d4-39db-42aa-89b1-8c19c9cd4c23}')
WIA_CATEGORY_AUTO: Guid = Guid('{defe5fd8-6c97-4dde-b11e-cb509b270e11}')
WIA_CATEGORY_IMPRINTER: Guid = Guid('{fc65016d-9202-43dd-91a7-64c2954cfb8b}')
WIA_CATEGORY_ENDORSER: Guid = Guid('{47102cc3-127f-4771-adfc-991ab8ee1e97}')
WIA_CATEGORY_BARCODE_READER: Guid = Guid('{36e178a0-473f-494b-af8f-6c3f6d7486fc}')
WIA_CATEGORY_PATCH_CODE_READER: Guid = Guid('{8faa1a6d-9c8a-42cd-98b3-ee9700cbc74f}')
WIA_CATEGORY_MICR_READER: Guid = Guid('{3b86c1ec-71bc-4645-b4d5-1b19da2be978}')
CLSID_WiaDefaultSegFilter: Guid = Guid('{d4f4d30b-0b29-4508-8922-0c5797d42765}')
WIA_TRANSFER_CHILDREN_SINGLE_SCAN: UInt32 = 1
WIA_USE_SEGMENTATION_FILTER: UInt32 = 0
WIA_DONT_USE_SEGMENTATION_FILTER: UInt32 = 1
WIA_FILM_COLOR_SLIDE: UInt32 = 0
WIA_FILM_COLOR_NEGATIVE: UInt32 = 1
WIA_FILM_BW_NEGATIVE: UInt32 = 2
WIA_LAMP_ON: UInt32 = 0
WIA_LAMP_OFF: UInt32 = 1
WIA_AUTO_DESKEW_ON: UInt32 = 0
WIA_AUTO_DESKEW_OFF: UInt32 = 1
WIA_ADVANCED_PREVIEW: UInt32 = 0
WIA_BASIC_PREVIEW: UInt32 = 1
WIA_PRINTER_ENDORSER_DISABLED: UInt32 = 0
WIA_PRINTER_ENDORSER_AUTO: UInt32 = 1
WIA_PRINTER_ENDORSER_FLATBED: UInt32 = 2
WIA_PRINTER_ENDORSER_FEEDER_FRONT: UInt32 = 3
WIA_PRINTER_ENDORSER_FEEDER_BACK: UInt32 = 4
WIA_PRINTER_ENDORSER_FEEDER_DUPLEX: UInt32 = 5
WIA_PRINTER_ENDORSER_DIGITAL: UInt32 = 6
WIA_PRINTER_ENDORSER_BEFORE_SCAN: UInt32 = 0
WIA_PRINTER_ENDORSER_AFTER_SCAN: UInt32 = 1
WIA_PRINT_DATE: UInt32 = 0
WIA_PRINT_YEAR: UInt32 = 1
WIA_PRINT_MONTH: UInt32 = 2
WIA_PRINT_DAY: UInt32 = 3
WIA_PRINT_WEEK_DAY: UInt32 = 4
WIA_PRINT_TIME_24H: UInt32 = 5
WIA_PRINT_TIME_12H: UInt32 = 6
WIA_PRINT_HOUR_24H: UInt32 = 7
WIA_PRINT_HOUR_12H: UInt32 = 8
WIA_PRINT_AM_PM: UInt32 = 9
WIA_PRINT_MINUTE: UInt32 = 10
WIA_PRINT_SECOND: UInt32 = 11
WIA_PRINT_PAGE_COUNT: UInt32 = 12
WIA_PRINT_IMAGE: UInt32 = 13
WIA_PRINT_MILLISECOND: UInt32 = 14
WIA_PRINT_MONTH_NAME: UInt32 = 15
WIA_PRINT_MONTH_SHORT: UInt32 = 16
WIA_PRINT_WEEK_DAY_SHORT: UInt32 = 17
WIA_PRINTER_ENDORSER_GRAPHICS_LEFT: UInt32 = 0
WIA_PRINTER_ENDORSER_GRAPHICS_RIGHT: UInt32 = 1
WIA_PRINTER_ENDORSER_GRAPHICS_TOP: UInt32 = 2
WIA_PRINTER_ENDORSER_GRAPHICS_BOTTOM: UInt32 = 3
WIA_PRINTER_ENDORSER_GRAPHICS_TOP_LEFT: UInt32 = 4
WIA_PRINTER_ENDORSER_GRAPHICS_TOP_RIGHT: UInt32 = 5
WIA_PRINTER_ENDORSER_GRAPHICS_BOTTOM_LEFT: UInt32 = 6
WIA_PRINTER_ENDORSER_GRAPHICS_BOTTOM_RIGHT: UInt32 = 7
WIA_PRINTER_ENDORSER_GRAPHICS_BACKGROUND: UInt32 = 8
WIA_PRINTER_ENDORSER_GRAPHICS_DEVICE_DEFAULT: UInt32 = 9
WIA_BARCODE_READER_DISABLED: UInt32 = 0
WIA_BARCODE_READER_AUTO: UInt32 = 1
WIA_BARCODE_READER_FLATBED: UInt32 = 2
WIA_BARCODE_READER_FEEDER_FRONT: UInt32 = 3
WIA_BARCODE_READER_FEEDER_BACK: UInt32 = 4
WIA_BARCODE_READER_FEEDER_DUPLEX: UInt32 = 5
WIA_BARCODE_HORIZONTAL_SEARCH: UInt32 = 0
WIA_BARCODE_VERTICAL_SEARCH: UInt32 = 1
WIA_BARCODE_HORIZONTAL_VERTICAL_SEARCH: UInt32 = 2
WIA_BARCODE_VERTICAL_HORIZONTAL_SEARCH: UInt32 = 3
WIA_BARCODE_AUTO_SEARCH: UInt32 = 4
WIA_BARCODE_UPCA: UInt32 = 0
WIA_BARCODE_UPCE: UInt32 = 1
WIA_BARCODE_CODABAR: UInt32 = 2
WIA_BARCODE_NONINTERLEAVED_2OF5: UInt32 = 3
WIA_BARCODE_INTERLEAVED_2OF5: UInt32 = 4
WIA_BARCODE_CODE39: UInt32 = 5
WIA_BARCODE_CODE39_MOD43: UInt32 = 6
WIA_BARCODE_CODE39_FULLASCII: UInt32 = 7
WIA_BARCODE_CODE93: UInt32 = 8
WIA_BARCODE_CODE128: UInt32 = 9
WIA_BARCODE_CODE128A: UInt32 = 10
WIA_BARCODE_CODE128B: UInt32 = 11
WIA_BARCODE_CODE128C: UInt32 = 12
WIA_BARCODE_GS1128: UInt32 = 13
WIA_BARCODE_GS1DATABAR: UInt32 = 14
WIA_BARCODE_ITF14: UInt32 = 15
WIA_BARCODE_EAN8: UInt32 = 16
WIA_BARCODE_EAN13: UInt32 = 17
WIA_BARCODE_POSTNETA: UInt32 = 18
WIA_BARCODE_POSTNETB: UInt32 = 19
WIA_BARCODE_POSTNETC: UInt32 = 20
WIA_BARCODE_POSTNET_DPBC: UInt32 = 21
WIA_BARCODE_PLANET: UInt32 = 22
WIA_BARCODE_INTELLIGENT_MAIL: UInt32 = 23
WIA_BARCODE_POSTBAR: UInt32 = 24
WIA_BARCODE_RM4SCC: UInt32 = 25
WIA_BARCODE_HIGH_CAPACITY_COLOR: UInt32 = 26
WIA_BARCODE_MAXICODE: UInt32 = 27
WIA_BARCODE_PDF417: UInt32 = 28
WIA_BARCODE_CPCBINARY: UInt32 = 29
WIA_BARCODE_FIM: UInt32 = 30
WIA_BARCODE_PHARMACODE: UInt32 = 31
WIA_BARCODE_PLESSEY: UInt32 = 32
WIA_BARCODE_MSI: UInt32 = 33
WIA_BARCODE_JAN: UInt32 = 34
WIA_BARCODE_TELEPEN: UInt32 = 35
WIA_BARCODE_AZTEC: UInt32 = 36
WIA_BARCODE_SMALLAZTEC: UInt32 = 37
WIA_BARCODE_DATAMATRIX: UInt32 = 38
WIA_BARCODE_DATASTRIP: UInt32 = 39
WIA_BARCODE_EZCODE: UInt32 = 40
WIA_BARCODE_QRCODE: UInt32 = 41
WIA_BARCODE_SHOTCODE: UInt32 = 42
WIA_BARCODE_SPARQCODE: UInt32 = 43
WIA_BARCODE_CUSTOMBASE: UInt32 = 32768
WIA_PATCH_CODE_READER_DISABLED: UInt32 = 0
WIA_PATCH_CODE_READER_AUTO: UInt32 = 1
WIA_PATCH_CODE_READER_FLATBED: UInt32 = 2
WIA_PATCH_CODE_READER_FEEDER_FRONT: UInt32 = 3
WIA_PATCH_CODE_READER_FEEDER_BACK: UInt32 = 4
WIA_PATCH_CODE_READER_FEEDER_DUPLEX: UInt32 = 5
WIA_PATCH_CODE_UNKNOWN: UInt32 = 0
WIA_PATCH_CODE_1: UInt32 = 1
WIA_PATCH_CODE_2: UInt32 = 2
WIA_PATCH_CODE_3: UInt32 = 3
WIA_PATCH_CODE_4: UInt32 = 4
WIA_PATCH_CODE_T: UInt32 = 5
WIA_PATCH_CODE_6: UInt32 = 6
WIA_PATCH_CODE_7: UInt32 = 7
WIA_PATCH_CODE_8: UInt32 = 8
WIA_PATCH_CODE_9: UInt32 = 9
WIA_PATCH_CODE_10: UInt32 = 10
WIA_PATCH_CODE_11: UInt32 = 11
WIA_PATCH_CODE_12: UInt32 = 12
WIA_PATCH_CODE_13: UInt32 = 13
WIA_PATCH_CODE_14: UInt32 = 14
WIA_PATCH_CODE_CUSTOM_BASE: UInt32 = 32768
WIA_MICR_READER_DISABLED: UInt32 = 0
WIA_MICR_READER_AUTO: UInt32 = 1
WIA_MICR_READER_FLATBED: UInt32 = 2
WIA_MICR_READER_FEEDER_FRONT: UInt32 = 3
WIA_MICR_READER_FEEDER_BACK: UInt32 = 4
WIA_MICR_READER_FEEDER_DUPLEX: UInt32 = 5
WIA_SEPARATOR_DISABLED: UInt32 = 0
WIA_SEPARATOR_DETECT_SCAN_CONTINUE: UInt32 = 1
WIA_SEPARATOR_DETECT_SCAN_STOP: UInt32 = 2
WIA_SEPARATOR_DETECT_NOSCAN_CONTINUE: UInt32 = 3
WIA_SEPARATOR_DETECT_NOSCAN_STOP: UInt32 = 4
WIA_LONG_DOCUMENT_DISABLED: UInt32 = 0
WIA_LONG_DOCUMENT_ENABLED: UInt32 = 1
WIA_LONG_DOCUMENT_SPLIT: UInt32 = 2
WIA_BLANK_PAGE_DETECTION_DISABLED: UInt32 = 0
WIA_BLANK_PAGE_DISCARD: UInt32 = 1
WIA_BLANK_PAGE_JOB_SEPARATOR: UInt32 = 2
WIA_MULTI_FEED_DETECT_DISABLED: UInt32 = 0
WIA_MULTI_FEED_DETECT_STOP_ERROR: UInt32 = 1
WIA_MULTI_FEED_DETECT_STOP_SUCCESS: UInt32 = 2
WIA_MULTI_FEED_DETECT_CONTINUE: UInt32 = 3
WIA_MULTI_FEED_DETECT_METHOD_LENGTH: UInt32 = 0
WIA_MULTI_FEED_DETECT_METHOD_OVERLAP: UInt32 = 1
WIA_AUTO_CROP_DISABLED: UInt32 = 0
WIA_AUTO_CROP_SINGLE: UInt32 = 1
WIA_AUTO_CROP_MULTI: UInt32 = 2
WIA_OVER_SCAN_DISABLED: UInt32 = 0
WIA_OVER_SCAN_TOP_BOTTOM: UInt32 = 1
WIA_OVER_SCAN_LEFT_RIGHT: UInt32 = 2
WIA_OVER_SCAN_ALL: UInt32 = 3
WIA_COLOR_DROP_DISABLED: UInt32 = 0
WIA_COLOR_DROP_RED: UInt32 = 1
WIA_COLOR_DROP_GREEN: UInt32 = 2
WIA_COLOR_DROP_BLUE: UInt32 = 3
WIA_COLOR_DROP_RGB: UInt32 = 4
WIA_SCAN_AHEAD_DISABLED: UInt32 = 0
WIA_SCAN_AHEAD_ENABLED: UInt32 = 1
WIA_FEEDER_CONTROL_AUTO: UInt32 = 0
WIA_FEEDER_CONTROL_MANUAL: UInt32 = 1
WIA_PRINT_PADDING_NONE: UInt32 = 0
WIA_PRINT_PADDING_ZERO: UInt32 = 1
WIA_PRINT_PADDING_BLANK: UInt32 = 2
WIA_PRINT_FONT_NORMAL: UInt32 = 0
WIA_PRINT_FONT_BOLD: UInt32 = 1
WIA_PRINT_FONT_EXTRA_BOLD: UInt32 = 2
WIA_PRINT_FONT_ITALIC_BOLD: UInt32 = 3
WIA_PRINT_FONT_ITALIC_EXTRA_BOLD: UInt32 = 4
WIA_PRINT_FONT_ITALIC: UInt32 = 5
WIA_PRINT_FONT_SMALL: UInt32 = 6
WIA_PRINT_FONT_SMALL_BOLD: UInt32 = 7
WIA_PRINT_FONT_SMALL_EXTRA_BOLD: UInt32 = 8
WIA_PRINT_FONT_SMALL_ITALIC_BOLD: UInt32 = 9
WIA_PRINT_FONT_SMALL_ITALIC_EXTRA_BOLD: UInt32 = 10
WIA_PRINT_FONT_SMALL_ITALIC: UInt32 = 11
WIA_PRINT_FONT_LARGE: UInt32 = 12
WIA_PRINT_FONT_LARGE_BOLD: UInt32 = 13
WIA_PRINT_FONT_LARGE_EXTRA_BOLD: UInt32 = 14
WIA_PRINT_FONT_LARGE_ITALIC_BOLD: UInt32 = 15
WIA_PRINT_FONT_LARGE_ITALIC_EXTRA_BOLD: UInt32 = 16
WIA_PRINT_FONT_LARGE_ITALIC: UInt32 = 17
WIA_ALARM_NONE: UInt32 = 0
WIA_ALARM_BEEP1: UInt32 = 1
WIA_ALARM_BEEP2: UInt32 = 2
WIA_ALARM_BEEP3: UInt32 = 3
WIA_ALARM_BEEP4: UInt32 = 4
WIA_ALARM_BEEP5: UInt32 = 5
WIA_ALARM_BEEP6: UInt32 = 6
WIA_ALARM_BEEP7: UInt32 = 7
WIA_ALARM_BEEP8: UInt32 = 8
WIA_ALARM_BEEP9: UInt32 = 9
WIA_ALARM_BEEP10: UInt32 = 10
WIA_PRIVATE_DEVPROP: UInt32 = 38914
WIA_PRIVATE_ITEMPROP: UInt32 = 71682
WiaImgFmt_UNDEFINED: Guid = Guid('{b96b3ca9-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_RAWRGB: Guid = Guid('{bca48b55-f272-4371-b0f1-4a150d057bb4}')
WiaImgFmt_MEMORYBMP: Guid = Guid('{b96b3caa-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_BMP: Guid = Guid('{b96b3cab-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_EMF: Guid = Guid('{b96b3cac-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_WMF: Guid = Guid('{b96b3cad-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_JPEG: Guid = Guid('{b96b3cae-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_PNG: Guid = Guid('{b96b3caf-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_GIF: Guid = Guid('{b96b3cb0-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_TIFF: Guid = Guid('{b96b3cb1-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_EXIF: Guid = Guid('{b96b3cb2-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_PHOTOCD: Guid = Guid('{b96b3cb3-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_FLASHPIX: Guid = Guid('{b96b3cb4-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_ICO: Guid = Guid('{b96b3cb5-0728-11d3-9d7b-0000f81ef32e}')
WiaImgFmt_CIFF: Guid = Guid('{9821a8ab-3a7e-4215-94e0-d27a460c03b2}')
WiaImgFmt_PICT: Guid = Guid('{a6bc85d8-6b3e-40ee-a95c-25d482e41adc}')
WiaImgFmt_JPEG2K: Guid = Guid('{344ee2b2-39db-4dde-8173-c4b75f8f1e49}')
WiaImgFmt_JPEG2KX: Guid = Guid('{43e14614-c80a-4850-baf3-4b152dc8da27}')
WiaImgFmt_RAW: Guid = Guid('{6f120719-f1a8-4e07-9ade-9b64c63a3dcc}')
WiaImgFmt_JBIG: Guid = Guid('{41e8dd92-2f0a-43d4-8636-f1614ba11e46}')
WiaImgFmt_JBIG2: Guid = Guid('{bb8e7e67-283c-4235-9e59-0b9bf94ca687}')
WiaImgFmt_RTF: Guid = Guid('{573dd6a3-4834-432d-a9b5-e198dd9e890d}')
WiaImgFmt_XML: Guid = Guid('{b9171457-dac8-4884-b393-15b471d5f07e}')
WiaImgFmt_HTML: Guid = Guid('{c99a4e62-99de-4a94-acca-71956ac2977d}')
WiaImgFmt_TXT: Guid = Guid('{fafd4d82-723f-421f-9318-30501ac44b59}')
WiaImgFmt_PDFA: Guid = Guid('{9980bd5b-3463-43c7-bdca-3caa146f229f}')
WiaImgFmt_XPS: Guid = Guid('{700b4a0f-2011-411c-b430-d1e0b2e10b28}')
WiaImgFmt_OXPS: Guid = Guid('{2c7b1240-c14d-4109-9755-04b89025153a}')
WiaImgFmt_CSV: Guid = Guid('{355bda24-5a9f-4494-80dc-be752cecbc8c}')
WiaImgFmt_MPG: Guid = Guid('{ecd757e4-d2ec-4f57-955d-bcf8a97c4e52}')
WiaImgFmt_AVI: Guid = Guid('{32f8ca14-087c-4908-b7c4-6757fe7e90ab}')
WiaAudFmt_WAV: Guid = Guid('{f818e146-07af-40ff-ae55-be8f2c065dbe}')
WiaAudFmt_MP3: Guid = Guid('{0fbc71fb-43bf-49f2-9190-e6fecff37e54}')
WiaAudFmt_AIFF: Guid = Guid('{66e2bf4f-b6fc-443f-94c8-2f33c8a65aaf}')
WiaAudFmt_WMA: Guid = Guid('{d61d6413-8bc2-438f-93ad-21bd484db6a1}')
WiaImgFmt_ASF: Guid = Guid('{8d948ee9-d0aa-4a12-9d9a-9cc5de36199b}')
WiaImgFmt_SCRIPT: Guid = Guid('{fe7d6c53-2dac-446a-b0bd-d73e21e924c9}')
WiaImgFmt_EXEC: Guid = Guid('{485da097-141e-4aa5-bb3b-a5618d95d02b}')
WiaImgFmt_UNICODE16: Guid = Guid('{1b7639b6-6357-47d1-9a07-12452dc073e9}')
WiaImgFmt_DPOF: Guid = Guid('{369eeeab-a0e8-45ca-86a6-a83ce5697e28}')
WiaImgFmt_XMLBAR: Guid = Guid('{6235701c-3a98-484c-b2a8-fdffd87e6b16}')
WiaImgFmt_RAWBAR: Guid = Guid('{da63f833-d26e-451e-90d2-ea55a1365d62}')
WiaImgFmt_XMLPAT: Guid = Guid('{f8986f55-f052-460d-9523-3a7dfedbb33c}')
WiaImgFmt_RAWPAT: Guid = Guid('{7760507c-5064-400c-9a17-575624d8824b}')
WiaImgFmt_XMLMIC: Guid = Guid('{2d164c61-b9ae-4b23-8973-c7067e1fbd31}')
WiaImgFmt_RAWMIC: Guid = Guid('{22c4f058-0d88-409c-ac1c-eec12b0ea680}')
WIA_EVENT_DEVICE_DISCONNECTED: Guid = Guid('{143e4e83-6497-11d2-a231-00c04fa31809}')
WIA_EVENT_DEVICE_CONNECTED: Guid = Guid('{a28bbade-64b6-11d2-a231-00c04fa31809}')
WIA_EVENT_ITEM_DELETED: Guid = Guid('{1d22a559-e14f-11d2-b326-00c04f68ce61}')
WIA_EVENT_ITEM_CREATED: Guid = Guid('{4c8f4ef5-e14f-11d2-b326-00c04f68ce61}')
WIA_EVENT_TREE_UPDATED: Guid = Guid('{c9859b91-4ab2-4cd6-a1fc-582eec55e585}')
WIA_EVENT_VOLUME_INSERT: Guid = Guid('{9638bbfd-d1bd-11d2-b31f-00c04f68ce61}')
WIA_EVENT_SCAN_IMAGE: Guid = Guid('{a6c5a715-8c6e-11d2-977a-0000f87a926f}')
WIA_EVENT_SCAN_PRINT_IMAGE: Guid = Guid('{b441f425-8c6e-11d2-977a-0000f87a926f}')
WIA_EVENT_SCAN_FAX_IMAGE: Guid = Guid('{c00eb793-8c6e-11d2-977a-0000f87a926f}')
WIA_EVENT_SCAN_OCR_IMAGE: Guid = Guid('{9d095b89-37d6-4877-afed-62a297dc6dbe}')
WIA_EVENT_SCAN_EMAIL_IMAGE: Guid = Guid('{c686dcee-54f2-419e-9a27-2fc7f2e98f9e}')
WIA_EVENT_SCAN_FILM_IMAGE: Guid = Guid('{9b2b662c-6185-438c-b68b-e39ee25e71cb}')
WIA_EVENT_SCAN_IMAGE2: Guid = Guid('{fc4767c1-c8b3-48a2-9cfa-2e90cb3d3590}')
WIA_EVENT_SCAN_IMAGE3: Guid = Guid('{154e27be-b617-4653-acc5-0fd7bd4c65ce}')
WIA_EVENT_SCAN_IMAGE4: Guid = Guid('{a65b704a-7f3c-4447-a75d-8a26dfca1fdf}')
WIA_EVENT_STORAGE_CREATED: Guid = Guid('{353308b2-fe73-46c8-895e-fa4551ccc85a}')
WIA_EVENT_STORAGE_DELETED: Guid = Guid('{5e41e75e-9390-44c5-9a51-e47019e390cf}')
WIA_EVENT_STI_PROXY: Guid = Guid('{d711f81f-1f0d-422d-8641-927d1b93e5e5}')
WIA_EVENT_CANCEL_IO: Guid = Guid('{c860f7b8-9ccd-41ea-bbbf-4dd09c5b1795}')
WIA_EVENT_POWER_SUSPEND: Guid = Guid('{a0922ff9-c3b4-411c-9e29-03a66993d2be}')
WIA_EVENT_POWER_RESUME: Guid = Guid('{618f153e-f686-4350-9634-4115a304830c}')
WIA_EVENT_HANDLER_NO_ACTION: Guid = Guid('{e0372b7d-e115-4525-bc55-b629e68c745a}')
WIA_EVENT_HANDLER_PROMPT: Guid = Guid('{5f4baad0-4d59-4fcd-b213-783ce7a92f22}')
WIA_EVENT_DEVICE_NOT_READY: Guid = Guid('{d8962d7e-e4dc-4b4d-ba29-668a87f42e6f}')
WIA_EVENT_DEVICE_READY: Guid = Guid('{7523ec6c-988b-419e-9a0a-425ac31b37dc}')
WIA_EVENT_FLATBED_LID_OPEN: Guid = Guid('{ba0a0623-437d-4f03-a97d-7793b123113c}')
WIA_EVENT_FLATBED_LID_CLOSED: Guid = Guid('{f879af0f-9b29-4283-ad95-d412164d39a9}')
WIA_EVENT_FEEDER_LOADED: Guid = Guid('{cc8d701e-9aba-481d-bf74-78f763dc342a}')
WIA_EVENT_FEEDER_EMPTIED: Guid = Guid('{e70b4b82-6dda-46bb-8ff9-53ceb1a03e35}')
WIA_EVENT_COVER_OPEN: Guid = Guid('{19a12136-fa1c-4f66-900f-8f914ec74ec9}')
WIA_EVENT_COVER_CLOSED: Guid = Guid('{6714a1e6-e285-468c-9b8c-da7dc4cbaa05}')
WIA_CMD_SYNCHRONIZE: Guid = Guid('{9b26b7b2-acad-11d2-a093-00c04f72dc3c}')
WIA_CMD_TAKE_PICTURE: Guid = Guid('{af933cac-acad-11d2-a093-00c04f72dc3c}')
WIA_CMD_DELETE_ALL_ITEMS: Guid = Guid('{e208c170-acad-11d2-a093-00c04f72dc3c}')
WIA_CMD_CHANGE_DOCUMENT: Guid = Guid('{04e725b0-acae-11d2-a093-00c04f72dc3c}')
WIA_CMD_UNLOAD_DOCUMENT: Guid = Guid('{1f3b3d8e-acae-11d2-a093-00c04f72dc3c}')
WIA_CMD_DIAGNOSTIC: Guid = Guid('{10ff52f5-de04-4cf0-a5ad-691f8dce0141}')
WIA_CMD_FORMAT: Guid = Guid('{c3a693aa-f788-4d34-a5b0-be7190759a24}')
WIA_CMD_DELETE_DEVICE_TREE: Guid = Guid('{73815942-dbea-11d2-8416-00c04fa36145}')
WIA_CMD_BUILD_DEVICE_TREE: Guid = Guid('{9cba5ce0-dbea-11d2-8416-00c04fa36145}')
WIA_CMD_START_FEEDER: Guid = Guid('{5a9df6c9-5f2d-4a39-9d6c-00456d047f00}')
WIA_CMD_STOP_FEEDER: Guid = Guid('{d847b06d-3905-459c-9509-9b29cdb691e7}')
WIA_CMD_PAUSE_FEEDER: Guid = Guid('{50985e4d-a5b2-4b71-9c95-6d7d7c469a43}')
BASE_VAL_WIA_ERROR: UInt32 = 0
BASE_VAL_WIA_SUCCESS: UInt32 = 0
WIA_ERROR_GENERAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145320959
WIA_ERROR_PAPER_JAM: win32more.Windows.Win32.Foundation.HRESULT = -2145320958
WIA_ERROR_PAPER_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2145320957
WIA_ERROR_PAPER_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -2145320956
WIA_ERROR_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2145320955
WIA_ERROR_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2145320954
WIA_ERROR_WARMING_UP: win32more.Windows.Win32.Foundation.HRESULT = -2145320953
WIA_ERROR_USER_INTERVENTION: win32more.Windows.Win32.Foundation.HRESULT = -2145320952
WIA_ERROR_ITEM_DELETED: win32more.Windows.Win32.Foundation.HRESULT = -2145320951
WIA_ERROR_DEVICE_COMMUNICATION: win32more.Windows.Win32.Foundation.HRESULT = -2145320950
WIA_ERROR_INVALID_COMMAND: win32more.Windows.Win32.Foundation.HRESULT = -2145320949
WIA_ERROR_INCORRECT_HARDWARE_SETTING: win32more.Windows.Win32.Foundation.HRESULT = -2145320948
WIA_ERROR_DEVICE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2145320947
WIA_ERROR_EXCEPTION_IN_DRIVER: win32more.Windows.Win32.Foundation.HRESULT = -2145320946
WIA_ERROR_INVALID_DRIVER_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2145320945
WIA_ERROR_COVER_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2145320944
WIA_ERROR_LAMP_OFF: win32more.Windows.Win32.Foundation.HRESULT = -2145320943
WIA_ERROR_DESTINATION: win32more.Windows.Win32.Foundation.HRESULT = -2145320942
WIA_ERROR_NETWORK_RESERVATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145320941
WIA_ERROR_MULTI_FEED: win32more.Windows.Win32.Foundation.HRESULT = -2145320940
WIA_ERROR_MAXIMUM_PRINTER_ENDORSER_COUNTER: win32more.Windows.Win32.Foundation.HRESULT = -2145320939
WIA_STATUS_END_OF_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = 2162689
WIA_STATUS_WARMING_UP: win32more.Windows.Win32.Foundation.HRESULT = 2162690
WIA_STATUS_CALIBRATING: win32more.Windows.Win32.Foundation.HRESULT = 2162691
WIA_STATUS_RESERVING_NETWORK_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = 2162694
WIA_STATUS_NETWORK_DEVICE_RESERVED: win32more.Windows.Win32.Foundation.HRESULT = 2162695
WIA_STATUS_CLEAR: win32more.Windows.Win32.Foundation.HRESULT = 2162696
WIA_STATUS_SKIP_ITEM: win32more.Windows.Win32.Foundation.HRESULT = 2162697
WIA_STATUS_NOT_HANDLED: win32more.Windows.Win32.Foundation.HRESULT = 2162698
WIA_S_CHANGE_DEVICE: win32more.Windows.Win32.Foundation.HRESULT = 2162699
WIA_S_NO_DEVICE_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145320939
WIA_SELECT_DEVICE_NODEFAULT: UInt32 = 1
WIA_DEVICE_DIALOG_SINGLE_IMAGE: UInt32 = 2
WIA_DEVICE_DIALOG_USE_COMMON_UI: UInt32 = 4
WIA_REGISTER_EVENT_CALLBACK: UInt32 = 1
WIA_UNREGISTER_EVENT_CALLBACK: UInt32 = 2
WIA_SET_DEFAULT_HANDLER: UInt32 = 4
WIA_NOTIFICATION_EVENT: UInt32 = 1
WIA_ACTION_EVENT: UInt32 = 2
WIA_LINE_ORDER_TOP_TO_BOTTOM: UInt32 = 1
WIA_LINE_ORDER_BOTTOM_TO_TOP: UInt32 = 2
WIA_IS_DEFAULT_HANDLER: UInt32 = 1
WIA_EVENT_DEVICE_DISCONNECTED_STR: String = 'Device Disconnected'
WIA_EVENT_DEVICE_CONNECTED_STR: String = 'Device Connected'
TYMED_CALLBACK: UInt32 = 128
TYMED_MULTIPAGE_FILE: UInt32 = 256
TYMED_MULTIPAGE_CALLBACK: UInt32 = 512
IT_MSG_DATA_HEADER: UInt32 = 1
IT_MSG_DATA: UInt32 = 2
IT_MSG_STATUS: UInt32 = 3
IT_MSG_TERMINATION: UInt32 = 4
IT_MSG_NEW_PAGE: UInt32 = 5
IT_MSG_FILE_PREVIEW_DATA: UInt32 = 6
IT_MSG_FILE_PREVIEW_DATA_HEADER: UInt32 = 7
IT_STATUS_TRANSFER_FROM_DEVICE: UInt32 = 1
IT_STATUS_PROCESSING_DATA: UInt32 = 2
IT_STATUS_TRANSFER_TO_CLIENT: UInt32 = 4
IT_STATUS_MASK: UInt32 = 7
WIA_TRANSFER_ACQUIRE_CHILDREN: UInt32 = 1
WIA_TRANSFER_MSG_STATUS: UInt32 = 1
WIA_TRANSFER_MSG_END_OF_STREAM: UInt32 = 2
WIA_TRANSFER_MSG_END_OF_TRANSFER: UInt32 = 3
WIA_TRANSFER_MSG_DEVICE_STATUS: UInt32 = 5
WIA_TRANSFER_MSG_NEW_PAGE: UInt32 = 6
WIA_MAJOR_EVENT_DEVICE_CONNECT: UInt32 = 1
WIA_MAJOR_EVENT_DEVICE_DISCONNECT: UInt32 = 2
WIA_MAJOR_EVENT_PICTURE_TAKEN: UInt32 = 3
WIA_MAJOR_EVENT_PICTURE_DELETED: UInt32 = 4
WIA_DEVICE_NOT_CONNECTED: UInt32 = 0
WIA_DEVICE_CONNECTED: UInt32 = 1
WIA_DEVICE_COMMANDS: UInt32 = 1
WIA_DEVICE_EVENTS: UInt32 = 2
WIA_DEVINFO_ENUM_ALL: UInt32 = 15
WIA_DEVINFO_ENUM_LOCAL: UInt32 = 16
WiaItemTypeFree: UInt32 = 0
WiaItemTypeImage: UInt32 = 1
WiaItemTypeFile: UInt32 = 2
WiaItemTypeFolder: UInt32 = 4
WiaItemTypeRoot: UInt32 = 8
WiaItemTypeAnalyze: UInt32 = 16
WiaItemTypeAudio: UInt32 = 32
WiaItemTypeDevice: UInt32 = 64
WiaItemTypeDeleted: UInt32 = 128
WiaItemTypeDisconnected: UInt32 = 256
WiaItemTypeHPanorama: UInt32 = 512
WiaItemTypeVPanorama: UInt32 = 1024
WiaItemTypeBurst: UInt32 = 2048
WiaItemTypeStorage: UInt32 = 4096
WiaItemTypeTransfer: UInt32 = 8192
WiaItemTypeGenerated: UInt32 = 16384
WiaItemTypeHasAttachments: UInt32 = 32768
WiaItemTypeVideo: UInt32 = 65536
WiaItemTypeRemoved: UInt32 = 2147483648
WiaItemTypeDocument: UInt32 = 262144
WiaItemTypeProgrammableDataSource: UInt32 = 524288
WiaItemTypeMask: UInt32 = 2148532223
WIA_MAX_CTX_SIZE: UInt32 = 16777216
WIA_PROP_READ: UInt32 = 1
WIA_PROP_WRITE: UInt32 = 2
WIA_PROP_SYNC_REQUIRED: UInt32 = 4
WIA_PROP_NONE: UInt32 = 8
WIA_PROP_RANGE: UInt32 = 16
WIA_PROP_LIST: UInt32 = 32
WIA_PROP_FLAG: UInt32 = 64
WIA_PROP_CACHEABLE: UInt32 = 65536
COPY_PARENT_PROPERTY_VALUES: UInt32 = 1073741824
WIA_ITEM_CAN_BE_DELETED: UInt32 = 128
WIA_ITEM_READ: UInt32 = 1
WIA_ITEM_WRITE: UInt32 = 2
WIA_RANGE_MIN: UInt32 = 0
WIA_RANGE_NOM: UInt32 = 1
WIA_RANGE_MAX: UInt32 = 2
WIA_RANGE_STEP: UInt32 = 3
WIA_RANGE_NUM_ELEMS: UInt32 = 4
WIA_LIST_COUNT: UInt32 = 0
WIA_LIST_NOM: UInt32 = 1
WIA_LIST_VALUES: UInt32 = 2
WIA_LIST_NUM_ELEMS: UInt32 = 2
WIA_FLAG_NOM: UInt32 = 0
WIA_FLAG_VALUES: UInt32 = 1
WIA_FLAG_NUM_ELEMS: UInt32 = 2
WIA_DIP_FIRST: UInt32 = 2
WIA_IPA_FIRST: UInt32 = 4098
WIA_DPF_FIRST: UInt32 = 3330
WIA_IPS_FIRST: UInt32 = 6146
WIA_DPS_FIRST: UInt32 = 3074
WIA_IPC_FIRST: UInt32 = 5122
WIA_NUM_IPC: UInt32 = 9
WIA_RESERVED_FOR_NEW_PROPS: UInt32 = 1024
WHITEBALANCE_MANUAL: UInt32 = 1
WHITEBALANCE_AUTO: UInt32 = 2
WHITEBALANCE_ONEPUSH_AUTO: UInt32 = 3
WHITEBALANCE_DAYLIGHT: UInt32 = 4
WHITEBALANCE_FLORESCENT: UInt32 = 5
WHITEBALANCE_TUNGSTEN: UInt32 = 6
WHITEBALANCE_FLASH: UInt32 = 7
FOCUSMODE_MANUAL: UInt32 = 1
FOCUSMODE_AUTO: UInt32 = 2
FOCUSMODE_MACROAUTO: UInt32 = 3
EXPOSUREMETERING_AVERAGE: UInt32 = 1
EXPOSUREMETERING_CENTERWEIGHT: UInt32 = 2
EXPOSUREMETERING_MULTISPOT: UInt32 = 3
EXPOSUREMETERING_CENTERSPOT: UInt32 = 4
FLASHMODE_AUTO: UInt32 = 1
FLASHMODE_OFF: UInt32 = 2
FLASHMODE_FILL: UInt32 = 3
FLASHMODE_REDEYE_AUTO: UInt32 = 4
FLASHMODE_REDEYE_FILL: UInt32 = 5
FLASHMODE_EXTERNALSYNC: UInt32 = 6
EXPOSUREMODE_MANUAL: UInt32 = 1
EXPOSUREMODE_AUTO: UInt32 = 2
EXPOSUREMODE_APERTURE_PRIORITY: UInt32 = 3
EXPOSUREMODE_SHUTTER_PRIORITY: UInt32 = 4
EXPOSUREMODE_PROGRAM_CREATIVE: UInt32 = 5
EXPOSUREMODE_PROGRAM_ACTION: UInt32 = 6
EXPOSUREMODE_PORTRAIT: UInt32 = 7
CAPTUREMODE_NORMAL: UInt32 = 1
CAPTUREMODE_BURST: UInt32 = 2
CAPTUREMODE_TIMELAPSE: UInt32 = 3
EFFECTMODE_STANDARD: UInt32 = 1
EFFECTMODE_BW: UInt32 = 2
EFFECTMODE_SEPIA: UInt32 = 3
FOCUSMETERING_CENTERSPOT: UInt32 = 1
FOCUSMETERING_MULTISPOT: UInt32 = 2
POWERMODE_LINE: UInt32 = 1
POWERMODE_BATTERY: UInt32 = 2
LEFT_JUSTIFIED: UInt32 = 0
CENTERED: UInt32 = 1
RIGHT_JUSTIFIED: UInt32 = 2
TOP_JUSTIFIED: UInt32 = 0
BOTTOM_JUSTIFIED: UInt32 = 2
PORTRAIT: UInt32 = 0
LANSCAPE: UInt32 = 1
LANDSCAPE: UInt32 = 1
ROT180: UInt32 = 2
ROT270: UInt32 = 3
MIRRORED: UInt32 = 1
FEED: UInt32 = 1
FLAT: UInt32 = 2
DUP: UInt32 = 4
DETECT_FLAT: UInt32 = 8
DETECT_SCAN: UInt32 = 16
DETECT_FEED: UInt32 = 32
DETECT_DUP: UInt32 = 64
DETECT_FEED_AVAIL: UInt32 = 128
DETECT_DUP_AVAIL: UInt32 = 256
FILM_TPA: UInt32 = 512
DETECT_FILM_TPA: UInt32 = 1024
STOR: UInt32 = 2048
DETECT_STOR: UInt32 = 4096
ADVANCED_DUP: UInt32 = 8192
AUTO_SOURCE: UInt32 = 32768
IMPRINTER: UInt32 = 65536
ENDORSER: UInt32 = 131072
BARCODE_READER: UInt32 = 262144
PATCH_CODE_READER: UInt32 = 524288
MICR_READER: UInt32 = 1048576
FEED_READY: UInt32 = 1
FLAT_READY: UInt32 = 2
DUP_READY: UInt32 = 4
FLAT_COVER_UP: UInt32 = 8
PATH_COVER_UP: UInt32 = 16
PAPER_JAM: UInt32 = 32
FILM_TPA_READY: UInt32 = 64
STORAGE_READY: UInt32 = 128
STORAGE_FULL: UInt32 = 256
MULTIPLE_FEED: UInt32 = 512
DEVICE_ATTENTION: UInt32 = 1024
LAMP_ERR: UInt32 = 2048
IMPRINTER_READY: UInt32 = 4096
ENDORSER_READY: UInt32 = 8192
BARCODE_READER_READY: UInt32 = 16384
PATCH_CODE_READER_READY: UInt32 = 32768
MICR_READER_READY: UInt32 = 65536
FEEDER: UInt32 = 1
FLATBED: UInt32 = 2
DUPLEX: UInt32 = 4
FRONT_FIRST: UInt32 = 8
BACK_FIRST: UInt32 = 16
FRONT_ONLY: UInt32 = 32
BACK_ONLY: UInt32 = 64
NEXT_PAGE: UInt32 = 128
PREFEED: UInt32 = 256
AUTO_ADVANCE: UInt32 = 512
ADVANCED_DUPLEX: UInt32 = 1024
LIGHT_SOURCE_PRESENT_DETECT: UInt32 = 1
LIGHT_SOURCE_PRESENT: UInt32 = 2
LIGHT_SOURCE_DETECT_READY: UInt32 = 4
LIGHT_SOURCE_READY: UInt32 = 8
TRANSPARENCY_DYNAMIC_FRAME_SUPPORT: UInt32 = 1
TRANSPARENCY_STATIC_FRAME_SUPPORT: UInt32 = 2
LIGHT_SOURCE_SELECT: UInt32 = 1
LIGHT_SOURCE_POSITIVE: UInt32 = 2
LIGHT_SOURCE_NEGATIVE: UInt32 = 4
WIA_SCAN_AHEAD_ALL: UInt32 = 0
ALL_PAGES: UInt32 = 0
WIA_FINAL_SCAN: UInt32 = 0
WIA_PREVIEW_SCAN: UInt32 = 1
WIA_SHOW_PREVIEW_CONTROL: UInt32 = 0
WIA_DONT_SHOW_PREVIEW_CONTROL: UInt32 = 1
WIA_ENDORSER_TOK_DATE: String = '$DATE$'
WIA_ENDORSER_TOK_TIME: String = '$TIME$'
WIA_ENDORSER_TOK_PAGE_COUNT: String = '$PAGE_COUNT$'
WIA_ENDORSER_TOK_DAY: String = '$DAY$'
WIA_ENDORSER_TOK_MONTH: String = '$MONTH$'
WIA_ENDORSER_TOK_YEAR: String = '$YEAR$'
WIA_PAGE_A4: UInt32 = 0
WIA_PAGE_LETTER: UInt32 = 1
WIA_PAGE_CUSTOM: UInt32 = 2
WIA_PAGE_USLEGAL: UInt32 = 3
WIA_PAGE_USLETTER: UInt32 = 1
WIA_PAGE_USLEDGER: UInt32 = 4
WIA_PAGE_USSTATEMENT: UInt32 = 5
WIA_PAGE_BUSINESSCARD: UInt32 = 6
WIA_PAGE_ISO_A0: UInt32 = 7
WIA_PAGE_ISO_A1: UInt32 = 8
WIA_PAGE_ISO_A2: UInt32 = 9
WIA_PAGE_ISO_A3: UInt32 = 10
WIA_PAGE_ISO_A4: UInt32 = 0
WIA_PAGE_ISO_A5: UInt32 = 11
WIA_PAGE_ISO_A6: UInt32 = 12
WIA_PAGE_ISO_A7: UInt32 = 13
WIA_PAGE_ISO_A8: UInt32 = 14
WIA_PAGE_ISO_A9: UInt32 = 15
WIA_PAGE_ISO_A10: UInt32 = 16
WIA_PAGE_ISO_B0: UInt32 = 17
WIA_PAGE_ISO_B1: UInt32 = 18
WIA_PAGE_ISO_B2: UInt32 = 19
WIA_PAGE_ISO_B3: UInt32 = 20
WIA_PAGE_ISO_B4: UInt32 = 21
WIA_PAGE_ISO_B5: UInt32 = 22
WIA_PAGE_ISO_B6: UInt32 = 23
WIA_PAGE_ISO_B7: UInt32 = 24
WIA_PAGE_ISO_B8: UInt32 = 25
WIA_PAGE_ISO_B9: UInt32 = 26
WIA_PAGE_ISO_B10: UInt32 = 27
WIA_PAGE_ISO_C0: UInt32 = 28
WIA_PAGE_ISO_C1: UInt32 = 29
WIA_PAGE_ISO_C2: UInt32 = 30
WIA_PAGE_ISO_C3: UInt32 = 31
WIA_PAGE_ISO_C4: UInt32 = 32
WIA_PAGE_ISO_C5: UInt32 = 33
WIA_PAGE_ISO_C6: UInt32 = 34
WIA_PAGE_ISO_C7: UInt32 = 35
WIA_PAGE_ISO_C8: UInt32 = 36
WIA_PAGE_ISO_C9: UInt32 = 37
WIA_PAGE_ISO_C10: UInt32 = 38
WIA_PAGE_JIS_B0: UInt32 = 39
WIA_PAGE_JIS_B1: UInt32 = 40
WIA_PAGE_JIS_B2: UInt32 = 41
WIA_PAGE_JIS_B3: UInt32 = 42
WIA_PAGE_JIS_B4: UInt32 = 43
WIA_PAGE_JIS_B5: UInt32 = 44
WIA_PAGE_JIS_B6: UInt32 = 45
WIA_PAGE_JIS_B7: UInt32 = 46
WIA_PAGE_JIS_B8: UInt32 = 47
WIA_PAGE_JIS_B9: UInt32 = 48
WIA_PAGE_JIS_B10: UInt32 = 49
WIA_PAGE_JIS_2A: UInt32 = 50
WIA_PAGE_JIS_4A: UInt32 = 51
WIA_PAGE_DIN_2B: UInt32 = 52
WIA_PAGE_DIN_4B: UInt32 = 53
WIA_PAGE_AUTO: UInt32 = 100
WIA_PAGE_CUSTOM_BASE: UInt32 = 32768
WIA_COMPRESSION_NONE: UInt32 = 0
WIA_COMPRESSION_BI_RLE4: UInt32 = 1
WIA_COMPRESSION_BI_RLE8: UInt32 = 2
WIA_COMPRESSION_G3: UInt32 = 3
WIA_COMPRESSION_G4: UInt32 = 4
WIA_COMPRESSION_JPEG: UInt32 = 5
WIA_COMPRESSION_JBIG: UInt32 = 6
WIA_COMPRESSION_JPEG2K: UInt32 = 7
WIA_COMPRESSION_PNG: UInt32 = 8
WIA_COMPRESSION_AUTO: UInt32 = 100
WIA_PACKED_PIXEL: UInt32 = 0
WIA_PLANAR: UInt32 = 1
WIA_DATA_THRESHOLD: UInt32 = 0
WIA_DATA_DITHER: UInt32 = 1
WIA_DATA_GRAYSCALE: UInt32 = 2
WIA_DATA_COLOR: UInt32 = 3
WIA_DATA_COLOR_THRESHOLD: UInt32 = 4
WIA_DATA_COLOR_DITHER: UInt32 = 5
WIA_DATA_RAW_RGB: UInt32 = 6
WIA_DATA_RAW_BGR: UInt32 = 7
WIA_DATA_RAW_YUV: UInt32 = 8
WIA_DATA_RAW_YUVK: UInt32 = 9
WIA_DATA_RAW_CMY: UInt32 = 10
WIA_DATA_RAW_CMYK: UInt32 = 11
WIA_DATA_AUTO: UInt32 = 100
WIA_DEPTH_AUTO: UInt32 = 0
WIA_PHOTO_WHITE_1: UInt32 = 0
WIA_PHOTO_WHITE_0: UInt32 = 1
WIA_PROPPAGE_SCANNER_ITEM_GENERAL: UInt32 = 1
WIA_PROPPAGE_CAMERA_ITEM_GENERAL: UInt32 = 2
WIA_PROPPAGE_DEVICE_GENERAL: UInt32 = 4
WIA_INTENT_NONE: UInt32 = 0
WIA_INTENT_IMAGE_TYPE_COLOR: UInt32 = 1
WIA_INTENT_IMAGE_TYPE_GRAYSCALE: UInt32 = 2
WIA_INTENT_IMAGE_TYPE_TEXT: UInt32 = 4
WIA_INTENT_IMAGE_TYPE_MASK: UInt32 = 15
WIA_INTENT_MINIMIZE_SIZE: UInt32 = 65536
WIA_INTENT_MAXIMIZE_QUALITY: UInt32 = 131072
WIA_INTENT_BEST_PREVIEW: UInt32 = 262144
WIA_INTENT_SIZE_MASK: UInt32 = 983040
WIA_NUM_DIP: UInt32 = 16
SHELLEX_WIAUIEXTENSION_NAME: String = 'WiaDialogExtensionHandlers'
CFSTR_WIAITEMNAMES: String = 'WIAItemNames'
CFSTR_WIAITEMPTR: String = 'WIAItemPointer'
GUID_DEVINTERFACE_IMAGE: Guid = Guid('{6bdd1fc6-810f-11d0-bec7-08002be2092f}')
MAX_IO_HANDLES: UInt32 = 16
MAX_RESERVED: UInt32 = 4
MAX_ANSI_CHAR: UInt32 = 255
BUS_TYPE_SCSI: UInt32 = 200
BUS_TYPE_USB: UInt32 = 201
BUS_TYPE_PARALLEL: UInt32 = 202
BUS_TYPE_FIREWIRE: UInt32 = 203
SCAN_FIRST: UInt32 = 10
SCAN_NEXT: UInt32 = 20
SCAN_FINISHED: UInt32 = 30
SCANMODE_FINALSCAN: UInt32 = 0
SCANMODE_PREVIEWSCAN: UInt32 = 1
CMD_INITIALIZE: UInt32 = 100
CMD_UNINITIALIZE: UInt32 = 101
CMD_SETXRESOLUTION: UInt32 = 102
CMD_SETYRESOLUTION: UInt32 = 103
CMD_SETCONTRAST: UInt32 = 104
CMD_SETINTENSITY: UInt32 = 105
CMD_SETDATATYPE: UInt32 = 106
CMD_SETDITHER: UInt32 = 107
CMD_SETMIRROR: UInt32 = 108
CMD_SETNEGATIVE: UInt32 = 109
CMD_SETTONEMAP: UInt32 = 110
CMD_SETCOLORDITHER: UInt32 = 111
CMD_SETMATRIX: UInt32 = 112
CMD_SETSPEED: UInt32 = 113
CMD_SETFILTER: UInt32 = 114
CMD_LOAD_ADF: UInt32 = 115
CMD_UNLOAD_ADF: UInt32 = 116
CMD_GETADFAVAILABLE: UInt32 = 117
CMD_GETADFOPEN: UInt32 = 118
CMD_GETADFREADY: UInt32 = 119
CMD_GETADFHASPAPER: UInt32 = 120
CMD_GETADFSTATUS: UInt32 = 121
CMD_GETADFUNLOADREADY: UInt32 = 122
CMD_GETTPAAVAILABLE: UInt32 = 123
CMD_GETTPAOPENED: UInt32 = 124
CMD_TPAREADY: UInt32 = 125
CMD_SETLAMP: UInt32 = 126
CMD_SENDSCSICOMMAND: UInt32 = 127
CMD_STI_DEVICERESET: UInt32 = 128
CMD_STI_GETSTATUS: UInt32 = 129
CMD_STI_DIAGNOSTIC: UInt32 = 130
CMD_RESETSCANNER: UInt32 = 131
CMD_GETCAPABILITIES: UInt32 = 132
CMD_GET_INTERRUPT_EVENT: UInt32 = 133
CMD_SETGSDNAME: UInt32 = 134
CMD_SETSCANMODE: UInt32 = 135
CMD_SETSTIDEVICEHKEY: UInt32 = 136
CMD_GETSUPPORTEDFILEFORMATS: UInt32 = 138
CMD_GETSUPPORTEDMEMORYFORMATS: UInt32 = 139
CMD_SETFORMAT: UInt32 = 140
SUPPORT_COLOR: UInt32 = 1
SUPPORT_BW: UInt32 = 2
SUPPORT_GRAYSCALE: UInt32 = 4
MCRO_ERROR_GENERAL_ERROR: UInt32 = 0
MCRO_STATUS_OK: UInt32 = 1
MCRO_ERROR_PAPER_JAM: UInt32 = 2
MCRO_ERROR_PAPER_PROBLEM: UInt32 = 3
MCRO_ERROR_PAPER_EMPTY: UInt32 = 4
MCRO_ERROR_OFFLINE: UInt32 = 5
MCRO_ERROR_USER_INTERVENTION: UInt32 = 6
WIA_ORDER_RGB: UInt32 = 0
WIA_ORDER_BGR: UInt32 = 1
WiaItemTypeTwainCapabilityPassThrough: UInt32 = 131072
ESC_TWAIN_CAPABILITY: UInt32 = 2001
ESC_TWAIN_PRIVATE_SUPPORTED_CAPS: UInt32 = 2002
WIAU_DEBUG_TSTR: String = 'S'
g_dwDebugFlags: UInt32 = 0
WIA_WSD_MANUFACTURER: UInt32 = 38914
WIA_WSD_MANUFACTURER_STR: String = 'Device manufacturer'
WIA_WSD_MANUFACTURER_URL: UInt32 = 38915
WIA_WSD_MANUFACTURER_URL_STR: String = 'Manufacurer URL'
WIA_WSD_MODEL_NAME: UInt32 = 38916
WIA_WSD_MODEL_NAME_STR: String = 'Model name'
WIA_WSD_MODEL_NUMBER: UInt32 = 38917
WIA_WSD_MODEL_NUMBER_STR: String = 'Model number'
WIA_WSD_MODEL_URL: UInt32 = 38918
WIA_WSD_MODEL_URL_STR: String = 'Model URL'
WIA_WSD_PRESENTATION_URL: UInt32 = 38919
WIA_WSD_PRESENTATION_URL_STR: String = 'Presentation URL'
WIA_WSD_FRIENDLY_NAME: UInt32 = 38920
WIA_WSD_FRIENDLY_NAME_STR: String = 'Friendly name'
WIA_WSD_SERIAL_NUMBER: UInt32 = 38921
WIA_WSD_SERIAL_NUMBER_STR: String = 'Serial number'
WIA_WSD_SCAN_AVAILABLE_ITEM: UInt32 = 38922
WIA_WSD_SCAN_AVAILABLE_ITEM_STR: String = 'Scan Available Item'
class DEVICEDIALOGDATA(Structure):
    cbSize: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    pIWiaItemRoot: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem
    dwFlags: UInt32
    lIntent: Int32
    lItemCount: Int32
    ppWiaItems: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)
class DEVICEDIALOGDATA2(Structure):
    cbSize: UInt32
    pIWiaItemRoot: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2
    dwFlags: UInt32
    hwndParent: win32more.Windows.Win32.Foundation.HWND
    bstrFolderName: win32more.Windows.Win32.Foundation.BSTR
    bstrFilename: win32more.Windows.Win32.Foundation.BSTR
    lNumFiles: Int32
    pbstrFilePaths: POINTER(win32more.Windows.Win32.Foundation.BSTR)
    pWiaItem: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2
@winfunctype_pointer
def DeviceDialogFunction(param0: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.DEVICEDIALOGDATA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumWIA_DEV_CAPS(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1fcc4287-aca6-11d2-a093-00c04f72dc3c}')
    @commethod(3)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_DEV_CAP), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, pcelt: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumWIA_DEV_INFO(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5e38b83c-8cf1-11d1-bf92-0060081ed811}')
    @commethod(3)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaPropertyStorage), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, celt: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumWIA_FORMAT_INFO(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{81befc5b-656d-44f1-b24c-d41d51b4dc81}')
    @commethod(3)
    def Next(self, celt: UInt32, rgelt: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_FORMAT_INFO), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_FORMAT_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, pcelt: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumWiaItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5e8383fc-3391-11d2-9a33-00c04fa36145}')
    @commethod(3)
    def Next(self, celt: UInt32, ppIWiaItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem), pceltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, celt: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IEnumWiaItem2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{59970af4-cd0d-44d9-ab24-52295630e582}')
    @commethod(3)
    def Next(self, cElt: UInt32, ppIWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2), pcEltFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, cElt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCount(self, cElt: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaAppErrorHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c16186c-d0a6-400c-80f4-d26986a0e734}')
    @commethod(3)
    def GetWindow(self, phwnd: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReportStatus(self, lFlags: Int32, pWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, hrStatus: win32more.Windows.Win32.Foundation.HRESULT, lPercentComplete: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaDataCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a558a866-a5b0-11d2-a08f-00c04f72dc3c}')
    @commethod(3)
    def BandedDataCallback(self, lMessage: Int32, lStatus: Int32, lPercentComplete: Int32, lOffset: Int32, lLength: Int32, lReserved: Int32, lResLength: Int32, pbBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaDataTransfer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a6cef998-a5b0-11d2-a08f-00c04f72dc3c}')
    @commethod(3)
    def idtGetData(self, pMedium: POINTER(win32more.Windows.Win32.System.Com.STGMEDIUM), pIWiaDataCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDataCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def idtGetBandedData(self, pWiaDataTransInfo: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_DATA_TRANSFER_INFO), pIWiaDataCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDataCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def idtQueryGetData(self, pfe: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_FORMAT_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def idtEnumWIA_FORMAT_INFO(self, ppEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_FORMAT_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def idtGetExtendedTransferInfo(self, pExtendedTransferInfo: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_EXTENDED_TRANSFER_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaDevMgr(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5eb2502a-8cf1-11d1-bf92-0060081ed811}')
    @commethod(3)
    def EnumDeviceInfo(self, lFlag: Int32, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateDevice(self, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, ppWiaItemRoot: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SelectDeviceDlg(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lDeviceType: Int32, lFlags: Int32, pbstrDeviceID: POINTER(win32more.Windows.Win32.Foundation.BSTR), ppItemRoot: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SelectDeviceDlgID(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lDeviceType: Int32, lFlags: Int32, pbstrDeviceID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetImageDlg(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lDeviceType: Int32, lFlags: Int32, lIntent: Int32, pItemRoot: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem, bstrFilename: win32more.Windows.Win32.Foundation.BSTR, pguidFormat: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RegisterEventCallbackProgram(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, pEventGUID: POINTER(Guid), bstrCommandline: win32more.Windows.Win32.Foundation.BSTR, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrDescription: win32more.Windows.Win32.Foundation.BSTR, bstrIcon: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RegisterEventCallbackInterface(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, pEventGUID: POINTER(Guid), pIWiaEventCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaEventCallback, pEventObject: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RegisterEventCallbackCLSID(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, pEventGUID: POINTER(Guid), pClsID: POINTER(Guid), bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrDescription: win32more.Windows.Win32.Foundation.BSTR, bstrIcon: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def AddDeviceDlg(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaDevMgr2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{79c07cf1-cbdd-41ee-8ec3-f00080cada7a}')
    @commethod(3)
    def EnumDeviceInfo(self, lFlags: Int32, ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateDevice(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, ppWiaItem2Root: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SelectDeviceDlg(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lDeviceType: Int32, lFlags: Int32, pbstrDeviceID: POINTER(win32more.Windows.Win32.Foundation.BSTR), ppItemRoot: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SelectDeviceDlgID(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lDeviceType: Int32, lFlags: Int32, pbstrDeviceID: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RegisterEventCallbackInterface(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, pEventGUID: POINTER(Guid), pIWiaEventCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaEventCallback, pEventObject: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def RegisterEventCallbackProgram(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, pEventGUID: POINTER(Guid), bstrFullAppName: win32more.Windows.Win32.Foundation.BSTR, bstrCommandLineArg: win32more.Windows.Win32.Foundation.BSTR, bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrDescription: win32more.Windows.Win32.Foundation.BSTR, bstrIcon: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RegisterEventCallbackCLSID(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, pEventGUID: POINTER(Guid), pClsID: POINTER(Guid), bstrName: win32more.Windows.Win32.Foundation.BSTR, bstrDescription: win32more.Windows.Win32.Foundation.BSTR, bstrIcon: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetImageDlg(self, lFlags: Int32, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, bstrFolderName: win32more.Windows.Win32.Foundation.BSTR, bstrFilename: win32more.Windows.Win32.Foundation.BSTR, plNumFiles: POINTER(Int32), ppbstrFilePaths: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR)), ppItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaDrvItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1f02b5c5-b00c-11d2-a094-00c04f72dc3c}')
    @commethod(3)
    def GetItemFlags(self, __MIDL__IWiaDrvItem0000: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDeviceSpecContext(self, __MIDL__IWiaDrvItem0001: POINTER(POINTER(Byte))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFullItemName(self, __MIDL__IWiaDrvItem0002: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetItemName(self, __MIDL__IWiaDrvItem0003: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def AddItemToFolder(self, __MIDL__IWiaDrvItem0004: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def UnlinkItemTree(self, __MIDL__IWiaDrvItem0005: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RemoveItemFromFolder(self, __MIDL__IWiaDrvItem0006: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def FindItemByName(self, __MIDL__IWiaDrvItem0007: Int32, __MIDL__IWiaDrvItem0008: win32more.Windows.Win32.Foundation.BSTR, __MIDL__IWiaDrvItem0009: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def FindChildItemByName(self, __MIDL__IWiaDrvItem0010: win32more.Windows.Win32.Foundation.BSTR, __MIDL__IWiaDrvItem0011: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetParentItem(self, __MIDL__IWiaDrvItem0012: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetFirstChildItem(self, __MIDL__IWiaDrvItem0013: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetNextSiblingItem(self, __MIDL__IWiaDrvItem0014: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def DumpItemData(self, __MIDL__IWiaDrvItem0015: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaErrorHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0e4a51b1-bc1f-443d-a835-72e890759ef3}')
    @commethod(3)
    def ReportStatus(self, lFlags: Int32, hwndParent: win32more.Windows.Win32.Foundation.HWND, pWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, hrStatus: win32more.Windows.Win32.Foundation.HRESULT, lPercentComplete: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetStatusDescription(self, lFlags: Int32, pWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, hrStatus: win32more.Windows.Win32.Foundation.HRESULT, pbstrDescription: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaEventCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ae6287b0-0084-11d2-973b-00a0c9068f2e}')
    @commethod(3)
    def ImageEventCallback(self, pEventGUID: POINTER(Guid), bstrEventDescription: win32more.Windows.Win32.Foundation.BSTR, bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, bstrDeviceDescription: win32more.Windows.Win32.Foundation.BSTR, dwDeviceType: UInt32, bstrFullItemName: win32more.Windows.Win32.Foundation.BSTR, pulEventType: POINTER(UInt32), ulReserved: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaImageFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a8a79ffa-450b-41f1-8f87-849ccd94ebf6}')
    @commethod(3)
    def InitializeFilter(self, pWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, pWiaTransferCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaTransferCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetNewCallback(self, pWiaTransferCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaTransferCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FilterPreviewImage(self, lFlags: Int32, pWiaChildItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, InputImageExtents: win32more.Windows.Win32.Foundation.RECT, pInputStream: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ApplyProperties(self, pWiaPropertyStorage: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaPropertyStorage) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4db1ad10-3391-11d2-9a33-00c04fa36145}')
    @commethod(3)
    def GetItemType(self, pItemType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def AnalyzeItem(self, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumChildItems(self, ppIEnumWiaItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DeleteItem(self, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateChildItem(self, lFlags: Int32, bstrItemName: win32more.Windows.Win32.Foundation.BSTR, bstrFullItemName: win32more.Windows.Win32.Foundation.BSTR, ppIWiaItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def EnumRegisterEventInfo(self, lFlags: Int32, pEventGUID: POINTER(Guid), ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def FindItemByName(self, lFlags: Int32, bstrFullItemName: win32more.Windows.Win32.Foundation.BSTR, ppIWiaItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DeviceDlg(self, hwndParent: win32more.Windows.Win32.Foundation.HWND, lFlags: Int32, lIntent: Int32, plItemCount: POINTER(Int32), ppIWiaItem: POINTER(POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def DeviceCommand(self, lFlags: Int32, pCmdGUID: POINTER(Guid), pIWiaItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetRootItem(self, ppIWiaItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def EnumDeviceCapabilities(self, lFlags: Int32, ppIEnumWIA_DEV_CAPS: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def DumpItemData(self, bstrData: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def DumpDrvItemData(self, bstrData: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def DumpTreeItemData(self, bstrData: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Diagnostic(self, ulSize: UInt32, pBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaItem2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6cba0075-1287-407d-9b77-cf0e030435cc}')
    @commethod(3)
    def CreateChildItem(self, lItemFlags: Int32, lCreationFlags: Int32, bstrItemName: win32more.Windows.Win32.Foundation.BSTR, ppIWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def DeleteItem(self, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def EnumChildItems(self, pCategoryGUID: POINTER(Guid), ppIEnumWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FindItemByName(self, lFlags: Int32, bstrFullItemName: win32more.Windows.Win32.Foundation.BSTR, ppIWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetItemCategory(self, pItemCategoryGUID: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetItemType(self, pItemType: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DeviceDlg(self, lFlags: Int32, hwndParent: win32more.Windows.Win32.Foundation.HWND, bstrFolderName: win32more.Windows.Win32.Foundation.BSTR, bstrFilename: win32more.Windows.Win32.Foundation.BSTR, plNumFiles: POINTER(Int32), ppbstrFilePaths: POINTER(POINTER(win32more.Windows.Win32.Foundation.BSTR)), ppItem: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DeviceCommand(self, lFlags: Int32, pCmdGUID: POINTER(Guid), ppIWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def EnumDeviceCapabilities(self, lFlags: Int32, ppIEnumWIA_DEV_CAPS: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CheckExtension(self, lFlags: Int32, bstrName: win32more.Windows.Win32.Foundation.BSTR, riidExtensionInterface: POINTER(Guid), pbExtensionExists: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetExtension(self, lFlags: Int32, bstrName: win32more.Windows.Win32.Foundation.BSTR, riidExtensionInterface: POINTER(Guid), ppOut: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetParentItem(self, ppIWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetRootItem(self, ppIWiaItem2: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetPreviewComponent(self, lFlags: Int32, ppWiaPreview: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaPreview)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def EnumRegisterEventInfo(self, lFlags: Int32, pEventGUID: POINTER(Guid), ppIEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_DEV_CAPS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def Diagnostic(self, ulSize: UInt32, pBuffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaItemExtras(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6291ef2c-36ef-4532-876a-8e132593778d}')
    @commethod(3)
    def GetExtendedErrorInfo(self, bstrErrorText: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Escape(self, dwEscapeCode: UInt32, lpInData: POINTER(Byte), cbInDataSize: UInt32, pOutData: POINTER(Byte), dwOutDataSize: UInt32, pdwActualDataSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CancelPendingIO(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaLog(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a00c10b6-82a1-452f-8b6c-86062aad6890}')
    @commethod(3)
    def InitializeLog(self, hInstance: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def hResult(self, hResult: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Log(self, lFlags: Int32, lResID: Int32, lDetail: Int32, bstrText: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaLogEx(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{af1f22ac-7a40-4787-b421-aeb47a1fbd0b}')
    @commethod(3)
    def InitializeLogEx(self, hInstance: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def hResult(self, hResult: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Log(self, lFlags: Int32, lResID: Int32, lDetail: Int32, bstrText: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def hResultEx(self, lMethodId: Int32, hResult: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def LogEx(self, lMethodId: Int32, lFlags: Int32, lResID: Int32, lDetail: Int32, bstrText: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaMiniDrv(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d8cdee14-3c6c-11d2-9a35-00c04fa36145}')
    @commethod(3)
    def drvInitializeWia(self, __MIDL__IWiaMiniDrv0000: POINTER(Byte), __MIDL__IWiaMiniDrv0001: Int32, __MIDL__IWiaMiniDrv0002: win32more.Windows.Win32.Foundation.BSTR, __MIDL__IWiaMiniDrv0003: win32more.Windows.Win32.Foundation.BSTR, __MIDL__IWiaMiniDrv0004: win32more.Windows.Win32.System.Com.IUnknown, __MIDL__IWiaMiniDrv0005: win32more.Windows.Win32.System.Com.IUnknown, __MIDL__IWiaMiniDrv0006: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem), __MIDL__IWiaMiniDrv0007: POINTER(win32more.Windows.Win32.System.Com.IUnknown), __MIDL__IWiaMiniDrv0008: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def drvAcquireItemData(self, __MIDL__IWiaMiniDrv0009: POINTER(Byte), __MIDL__IWiaMiniDrv0010: Int32, __MIDL__IWiaMiniDrv0011: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.MINIDRV_TRANSFER_CONTEXT), __MIDL__IWiaMiniDrv0012: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def drvInitItemProperties(self, __MIDL__IWiaMiniDrv0013: POINTER(Byte), __MIDL__IWiaMiniDrv0014: Int32, __MIDL__IWiaMiniDrv0015: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def drvValidateItemProperties(self, __MIDL__IWiaMiniDrv0016: POINTER(Byte), __MIDL__IWiaMiniDrv0017: Int32, __MIDL__IWiaMiniDrv0018: UInt32, __MIDL__IWiaMiniDrv0019: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC), __MIDL__IWiaMiniDrv0020: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def drvWriteItemProperties(self, __MIDL__IWiaMiniDrv0021: POINTER(Byte), __MIDL__IWiaMiniDrv0022: Int32, __MIDL__IWiaMiniDrv0023: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.MINIDRV_TRANSFER_CONTEXT), __MIDL__IWiaMiniDrv0024: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def drvReadItemProperties(self, __MIDL__IWiaMiniDrv0025: POINTER(Byte), __MIDL__IWiaMiniDrv0026: Int32, __MIDL__IWiaMiniDrv0027: UInt32, __MIDL__IWiaMiniDrv0028: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC), __MIDL__IWiaMiniDrv0029: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def drvLockWiaDevice(self, __MIDL__IWiaMiniDrv0030: POINTER(Byte), __MIDL__IWiaMiniDrv0031: Int32, __MIDL__IWiaMiniDrv0032: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def drvUnLockWiaDevice(self, __MIDL__IWiaMiniDrv0033: POINTER(Byte), __MIDL__IWiaMiniDrv0034: Int32, __MIDL__IWiaMiniDrv0035: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def drvAnalyzeItem(self, __MIDL__IWiaMiniDrv0036: POINTER(Byte), __MIDL__IWiaMiniDrv0037: Int32, __MIDL__IWiaMiniDrv0038: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def drvGetDeviceErrorStr(self, __MIDL__IWiaMiniDrv0039: Int32, __MIDL__IWiaMiniDrv0040: Int32, __MIDL__IWiaMiniDrv0041: POINTER(win32more.Windows.Win32.Foundation.PWSTR), __MIDL__IWiaMiniDrv0042: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def drvDeviceCommand(self, __MIDL__IWiaMiniDrv0043: POINTER(Byte), __MIDL__IWiaMiniDrv0044: Int32, __MIDL__IWiaMiniDrv0045: POINTER(Guid), __MIDL__IWiaMiniDrv0046: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IWiaDrvItem), __MIDL__IWiaMiniDrv0047: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def drvGetCapabilities(self, __MIDL__IWiaMiniDrv0048: POINTER(Byte), __MIDL__IWiaMiniDrv0049: Int32, __MIDL__IWiaMiniDrv0050: POINTER(Int32), __MIDL__IWiaMiniDrv0051: POINTER(POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_DEV_CAP_DRV)), __MIDL__IWiaMiniDrv0052: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def drvDeleteItem(self, __MIDL__IWiaMiniDrv0053: POINTER(Byte), __MIDL__IWiaMiniDrv0054: Int32, __MIDL__IWiaMiniDrv0055: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def drvFreeDrvItemContext(self, __MIDL__IWiaMiniDrv0056: Int32, __MIDL__IWiaMiniDrv0057: POINTER(Byte), __MIDL__IWiaMiniDrv0058: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def drvGetWiaFormatInfo(self, __MIDL__IWiaMiniDrv0059: POINTER(Byte), __MIDL__IWiaMiniDrv0060: Int32, __MIDL__IWiaMiniDrv0061: POINTER(Int32), __MIDL__IWiaMiniDrv0062: POINTER(POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIA_FORMAT_INFO)), __MIDL__IWiaMiniDrv0063: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def drvNotifyPnpEvent(self, pEventGUID: POINTER(Guid), bstrDeviceID: win32more.Windows.Win32.Foundation.BSTR, ulReserved: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def drvUnInitializeWia(self, __MIDL__IWiaMiniDrv0064: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaMiniDrvCallBack(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{33a57d5a-3de8-11d2-9a36-00c04fa36145}')
    @commethod(3)
    def MiniDrvCallback(self, lReason: Int32, lStatus: Int32, lPercentComplete: Int32, lOffset: Int32, lLength: Int32, pTranCtx: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.MINIDRV_TRANSFER_CONTEXT), lReserved: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaMiniDrvTransferCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a9d2ee89-2ce5-4ff0-8adb-c961d1d774ca}')
    @commethod(3)
    def GetNextStream(self, lFlags: Int32, bstrItemName: win32more.Windows.Win32.Foundation.BSTR, bstrFullItemName: win32more.Windows.Win32.Foundation.BSTR, ppIStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SendMessage(self, lFlags: Int32, pWiaTransferParams: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WiaTransferParams)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaNotifyDevMgr(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{70681ea0-e7bf-4291-9fb1-4e8813a3f78e}')
    @commethod(3)
    def NewDeviceArrival(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaPreview(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{95c2b4fd-33f2-4d86-ad40-9431f0df08f7}')
    @commethod(3)
    def GetNewPreview(self, lFlags: Int32, pWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, pWiaTransferCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaTransferCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UpdatePreview(self, lFlags: Int32, pChildWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2, pWiaTransferCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaTransferCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DetectRegions(self, lFlags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaPropertyStorage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{98b5e8a0-29cc-491a-aac0-e6db4fdcceb6}')
    @commethod(3)
    def ReadMultiple(self, cpspec: UInt32, rgpspec: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC), rgpropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WriteMultiple(self, cpspec: UInt32, rgpspec: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC), rgpropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), propidNameFirst: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeleteMultiple(self, cpspec: UInt32, rgpspec: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def ReadPropertyNames(self, cpropid: UInt32, rgpropid: POINTER(UInt32), rglpwstrName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def WritePropertyNames(self, cpropid: UInt32, rgpropid: POINTER(UInt32), rglpwstrName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeletePropertyNames(self, cpropid: UInt32, rgpropid: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Commit(self, grfCommitFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Revert(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Enum(self, ppenum: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.IEnumSTATPROPSTG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetTimes(self, pctime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), patime: POINTER(win32more.Windows.Win32.Foundation.FILETIME), pmtime: POINTER(win32more.Windows.Win32.Foundation.FILETIME)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetClass(self, clsid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Stat(self, pstatpsstg: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.STATPROPSETSTG)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetPropertyAttributes(self, cpspec: UInt32, rgpspec: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPSPEC), rgflags: POINTER(UInt32), rgpropvar: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetCount(self, pulNumProps: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetPropertyStream(self, pCompatibilityId: POINTER(Guid), ppIStream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetPropertyStream(self, pCompatibilityId: POINTER(Guid), pIStream: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaSegmentationFilter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ec46a697-ac04-4447-8f65-ff63d5154b21}')
    @commethod(3)
    def DetectRegions(self, lFlags: Int32, pInputStream: win32more.Windows.Win32.System.Com.IStream, pWiaItem2: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaItem2) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaTransfer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c39d6942-2f4e-4d04-92fe-4ef4d3a1de5a}')
    @commethod(3)
    def Download(self, lFlags: Int32, pIWiaTransferCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaTransferCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Upload(self, lFlags: Int32, pSource: win32more.Windows.Win32.System.Com.IStream, pIWiaTransferCallback: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaTransferCallback) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def EnumWIA_FORMAT_INFO(self, ppEnum: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.IEnumWIA_FORMAT_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaTransferCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{27d4eaaf-28a6-4ca5-9aab-e678168b9527}')
    @commethod(3)
    def TransferCallback(self, lFlags: Int32, pWiaTransferParams: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WiaTransferParams)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNextStream(self, lFlags: Int32, bstrItemName: win32more.Windows.Win32.Foundation.BSTR, bstrFullItemName: win32more.Windows.Win32.Foundation.BSTR, ppDestination: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaUIExtension(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{da319113-50ee-4c80-b460-57d005d44a2c}')
    @commethod(3)
    def DeviceDialog(self, pDeviceDialogData: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.DEVICEDIALOGDATA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDeviceIcon(self, bstrDeviceId: win32more.Windows.Win32.Foundation.BSTR, phIcon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON), nSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDeviceBitmapLogo(self, bstrDeviceId: win32more.Windows.Win32.Foundation.BSTR, phBitmap: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP), nMaxWidth: UInt32, nMaxHeight: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaUIExtension2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{305600d7-5088-46d7-9a15-b77b09cdba7a}')
    @commethod(3)
    def DeviceDialog(self, pDeviceDialogData: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.DEVICEDIALOGDATA2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDeviceIcon(self, bstrDeviceId: win32more.Windows.Win32.Foundation.BSTR, phIcon: POINTER(win32more.Windows.Win32.UI.WindowsAndMessaging.HICON), nSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWiaVideo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d52920aa-db88-41f0-946c-e00dc0a19cfa}')
    @commethod(3)
    def get_PreviewVisible(self, pbPreviewVisible: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def put_PreviewVisible(self, bPreviewVisible: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_ImagesDirectory(self, pbstrImageDirectory: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def put_ImagesDirectory(self, bstrImageDirectory: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateVideoByWiaDevID(self, bstrWiaDeviceID: win32more.Windows.Win32.Foundation.BSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, bStretchToFitParent: win32more.Windows.Win32.Foundation.BOOL, bAutoBeginPlayback: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateVideoByDevNum(self, uiDeviceNumber: UInt32, hwndParent: win32more.Windows.Win32.Foundation.HWND, bStretchToFitParent: win32more.Windows.Win32.Foundation.BOOL, bAutoBeginPlayback: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateVideoByName(self, bstrFriendlyName: win32more.Windows.Win32.Foundation.BSTR, hwndParent: win32more.Windows.Win32.Foundation.HWND, bStretchToFitParent: win32more.Windows.Win32.Foundation.BOOL, bAutoBeginPlayback: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def DestroyVideo(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Play(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def TakePicture(self, pbstrNewImageFilename: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def ResizeVideo(self, bStretchToFitParent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCurrentState(self, pState: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class MINIDRV_TRANSFER_CONTEXT(Structure):
    lSize: Int32
    lWidthInPixels: Int32
    lLines: Int32
    lDepth: Int32
    lXRes: Int32
    lYRes: Int32
    lCompression: Int32
    guidFormatID: Guid
    tymed: Int32
    hFile: IntPtr
    cbOffset: Int32
    lBufferSize: Int32
    lActiveBuffer: Int32
    lNumBuffers: Int32
    pBaseBuffer: POINTER(Byte)
    pTransferBuffer: POINTER(Byte)
    bTransferDataCB: win32more.Windows.Win32.Foundation.BOOL
    bClassDrvAllocBuf: win32more.Windows.Win32.Foundation.BOOL
    lClientAddress: IntPtr
    pIWiaMiniDrvCallBack: win32more.Windows.Win32.Devices.ImageAcquisition.IWiaMiniDrvCallBack
    lImageSize: Int32
    lHeaderSize: Int32
    lItemSize: Int32
    cbWidthInBytes: Int32
    lPage: Int32
    lCurIfdOffset: Int32
    lPrevIfdOffset: Int32
class RANGEVALUE(Structure):
    lMin: Int32
    lMax: Int32
    lStep: Int32
class SCANINFO(Structure):
    ADF: Int32
    TPA: Int32
    Endorser: Int32
    OpticalXResolution: Int32
    OpticalYResolution: Int32
    BedWidth: Int32
    BedHeight: Int32
    IntensityRange: win32more.Windows.Win32.Devices.ImageAcquisition.RANGEVALUE
    ContrastRange: win32more.Windows.Win32.Devices.ImageAcquisition.RANGEVALUE
    SupportedCompressionType: Int32
    SupportedDataTypes: Int32
    WidthPixels: Int32
    WidthBytes: Int32
    Lines: Int32
    DataType: Int32
    PixelBits: Int32
    Intensity: Int32
    Contrast: Int32
    Xresolution: Int32
    Yresolution: Int32
    Window: win32more.Windows.Win32.Devices.ImageAcquisition.SCANWINDOW
    DitherPattern: Int32
    Negative: Int32
    Mirror: Int32
    AutoBack: Int32
    ColorDitherPattern: Int32
    ToneMap: Int32
    Compression: Int32
    RawDataFormat: Int32
    RawPixelOrder: Int32
    bNeedDataAlignment: Int32
    DelayBetweenRead: Int32
    MaxBufferSize: Int32
    DeviceIOHandles: win32more.Windows.Win32.Foundation.HANDLE * 16
    lReserved: Int32 * 4
    pMicroDriverContext: VoidPtr
class SCANWINDOW(Structure):
    xPos: Int32
    yPos: Int32
    xExtent: Int32
    yExtent: Int32
class TWAIN_CAPABILITY(Structure):
    lSize: Int32
    lMSG: Int32
    lCapID: Int32
    lConType: Int32
    lRC: Int32
    lCC: Int32
    lDataSize: Int32
    Data: Byte * 1
class VAL(Structure):
    lVal: Int32
    dblVal: Double
    pGuid: POINTER(Guid)
    pScanInfo: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.SCANINFO)
    handle: win32more.Windows.Win32.Foundation.HGLOBAL
    ppButtonNames: POINTER(POINTER(UInt16))
    pHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)
    lReserved: Int32
    szVal: win32more.Windows.Win32.Foundation.CHAR * 255
class WIAS_CHANGED_VALUE_INFO(Structure):
    bChanged: win32more.Windows.Win32.Foundation.BOOL
    vt: Int32
    Old: _Old_e__Union
    Current: _Current_e__Union
    class _Old_e__Union(Union):
        lVal: Int32
        fltVal: Single
        bstrVal: win32more.Windows.Win32.Foundation.BSTR
        guidVal: Guid
    class _Current_e__Union(Union):
        lVal: Int32
        fltVal: Single
        bstrVal: win32more.Windows.Win32.Foundation.BSTR
        guidVal: Guid
class WIAS_DOWN_SAMPLE_INFO(Structure):
    ulOriginalWidth: UInt32
    ulOriginalHeight: UInt32
    ulBitsPerPixel: UInt32
    ulXRes: UInt32
    ulYRes: UInt32
    ulDownSampledWidth: UInt32
    ulDownSampledHeight: UInt32
    ulActualSize: UInt32
    ulDestBufSize: UInt32
    ulSrcBufSize: UInt32
    pSrcBuffer: POINTER(Byte)
    pDestBuffer: POINTER(Byte)
class WIAS_ENDORSER_INFO(Structure):
    ulPageCount: UInt32
    ulNumEndorserValues: UInt32
    pEndorserValues: POINTER(win32more.Windows.Win32.Devices.ImageAcquisition.WIAS_ENDORSER_VALUE)
class WIAS_ENDORSER_VALUE(Structure):
    wszTokenName: win32more.Windows.Win32.Foundation.PWSTR
    wszValue: win32more.Windows.Win32.Foundation.PWSTR
WIAVIDEO_STATE = Int32
WIAVIDEO_NO_VIDEO: win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE = 1
WIAVIDEO_CREATING_VIDEO: win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE = 2
WIAVIDEO_VIDEO_CREATED: win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE = 3
WIAVIDEO_VIDEO_PLAYING: win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE = 4
WIAVIDEO_VIDEO_PAUSED: win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE = 5
WIAVIDEO_DESTROYING_VIDEO: win32more.Windows.Win32.Devices.ImageAcquisition.WIAVIDEO_STATE = 6
class WIA_BARCODES(Structure):
    Tag: UInt32
    Version: UInt32
    Size: UInt32
    Count: UInt32
    Barcodes: win32more.Windows.Win32.Devices.ImageAcquisition.WIA_BARCODE_INFO * 1
class WIA_BARCODE_INFO(Structure):
    Size: UInt32
    Type: UInt32
    Page: UInt32
    Confidence: UInt32
    XOffset: UInt32
    YOffset: UInt32
    Rotation: UInt32
    Length: UInt32
    Text: Char * 1
class WIA_DATA_CALLBACK_HEADER(Structure):
    lSize: Int32
    guidFormatID: Guid
    lBufferSize: Int32
    lPageCount: Int32
class WIA_DATA_TRANSFER_INFO(Structure):
    ulSize: UInt32
    ulSection: UInt32
    ulBufferSize: UInt32
    bDoubleBuffer: win32more.Windows.Win32.Foundation.BOOL
    ulReserved1: UInt32
    ulReserved2: UInt32
    ulReserved3: UInt32
class WIA_DEV_CAP(Structure):
    guid: Guid
    ulFlags: UInt32
    bstrName: win32more.Windows.Win32.Foundation.BSTR
    bstrDescription: win32more.Windows.Win32.Foundation.BSTR
    bstrIcon: win32more.Windows.Win32.Foundation.BSTR
    bstrCommandline: win32more.Windows.Win32.Foundation.BSTR
class WIA_DEV_CAP_DRV(Structure):
    guid: POINTER(Guid)
    ulFlags: UInt32
    wszName: win32more.Windows.Win32.Foundation.PWSTR
    wszDescription: win32more.Windows.Win32.Foundation.PWSTR
    wszIcon: win32more.Windows.Win32.Foundation.PWSTR
class WIA_DITHER_PATTERN_DATA(Structure):
    lSize: Int32
    bstrPatternName: win32more.Windows.Win32.Foundation.BSTR
    lPatternWidth: Int32
    lPatternLength: Int32
    cbPattern: Int32
    pbPattern: POINTER(Byte)
class WIA_EXTENDED_TRANSFER_INFO(Structure):
    ulSize: UInt32
    ulMinBufferSize: UInt32
    ulOptimalBufferSize: UInt32
    ulMaxBufferSize: UInt32
    ulNumBuffers: UInt32
class WIA_FORMAT_INFO(Structure):
    guidFormatID: Guid
    lTymed: Int32
class WIA_MICR(Structure):
    Tag: UInt32
    Version: UInt32
    Size: UInt32
    Placeholder: Char
    Reserved: UInt16
    Count: UInt32
    Micr: win32more.Windows.Win32.Devices.ImageAcquisition.WIA_MICR_INFO * 1
class WIA_MICR_INFO(Structure):
    Size: UInt32
    Page: UInt32
    Length: UInt32
    Text: Char * 1
class WIA_PATCH_CODES(Structure):
    Tag: UInt32
    Version: UInt32
    Size: UInt32
    Count: UInt32
    PatchCodes: win32more.Windows.Win32.Devices.ImageAcquisition.WIA_PATCH_CODE_INFO * 1
class WIA_PATCH_CODE_INFO(Structure):
    Type: UInt32
class WIA_PROPERTY_CONTEXT(Structure):
    cProps: UInt32
    pProps: POINTER(UInt32)
    pChanged: POINTER(win32more.Windows.Win32.Foundation.BOOL)
class WIA_PROPERTY_INFO(Structure):
    lAccessFlags: UInt32
    vt: win32more.Windows.Win32.System.Variant.VARENUM
    ValidVal: _ValidVal_e__Union
    class _ValidVal_e__Union(Union):
        Range: _Range_e__Struct
        RangeFloat: _RangeFloat_e__Struct
        List: _List_e__Struct
        ListFloat: _ListFloat_e__Struct
        ListGuid: _ListGuid_e__Struct
        ListBStr: _ListBStr_e__Struct
        Flag: _Flag_e__Struct
        None_: _None_e__Struct
        class _Range_e__Struct(Structure):
            Min: Int32
            Nom: Int32
            Max: Int32
            Inc: Int32
        class _RangeFloat_e__Struct(Structure):
            Min: Double
            Nom: Double
            Max: Double
            Inc: Double
        class _List_e__Struct(Structure):
            cNumList: Int32
            Nom: Int32
            pList: POINTER(Byte)
        class _ListFloat_e__Struct(Structure):
            cNumList: Int32
            Nom: Double
            pList: POINTER(Byte)
        class _ListGuid_e__Struct(Structure):
            cNumList: Int32
            Nom: Guid
            pList: POINTER(Guid)
        class _ListBStr_e__Struct(Structure):
            cNumList: Int32
            Nom: win32more.Windows.Win32.Foundation.BSTR
            pList: POINTER(win32more.Windows.Win32.Foundation.BSTR)
        class _Flag_e__Struct(Structure):
            Nom: Int32
            ValidBits: Int32
        class _None_e__Struct(Structure):
            Dummy: Int32
class WIA_PROPID_TO_NAME(Structure):
    propid: UInt32
    pszName: win32more.Windows.Win32.Foundation.PWSTR
class WIA_RAW_HEADER(Structure):
    Tag: UInt32
    Version: UInt32
    HeaderSize: UInt32
    XRes: UInt32
    YRes: UInt32
    XExtent: UInt32
    YExtent: UInt32
    BytesPerLine: UInt32
    BitsPerPixel: UInt32
    ChannelsPerPixel: UInt32
    DataType: UInt32
    BitsPerChannel: Byte * 8
    Compression: UInt32
    PhotometricInterp: UInt32
    LineOrder: UInt32
    RawDataOffset: UInt32
    RawDataSize: UInt32
    PaletteOffset: UInt32
    PaletteSize: UInt32
WiaDevMgr = Guid('{a1f4e726-8cf1-11d1-bf92-0060081ed811}')
WiaDevMgr2 = Guid('{b6c292bc-7c88-41ee-8b54-8ec92617e599}')
WiaLog = Guid('{a1e75357-881a-419e-83e2-bb16db197c68}')
class WiaTransferParams(Structure):
    lMessage: Int32
    lPercentComplete: Int32
    ulTransferredBytes: UInt64
    hrErrorStatus: win32more.Windows.Win32.Foundation.HRESULT
WiaVideo = Guid('{3908c3cd-4478-4536-af2f-10c25d4ef89a}')


make_ready(__name__)
